@@ -14,7 +14,7 @@
 #include <lslutils/conversion.h>
 
 #include "battle.h"
-#include "ui.h"
+#include "gui/ui.h"
 #include "iserver.h"
 #include "user.h"
 #include "utils/conversion.h"
@@ -22,10 +22,10 @@
 #include "utils/uievents.h"
 #include "utils/battleevents.h"
 #include "utils/slpaths.h"
-#include "uiutils.h"
+#include "gui/uiutils.h"
 #include "settings.h"
 #include "useractions.h"
-#include "utils/customdialogs.h"
+#include "gui/customdialogs.h"
 #include "iconimagelist.h"
 #include "spring.h"
 #include "utils/conversion.h"
@@ -34,13 +34,15 @@
 
 
 const unsigned int TIMER_INTERVAL         = 1000;
-const unsigned int TIMER_ID               = 101;
+const unsigned int TIMER_ID               = wxNewId();
 
 BEGIN_EVENT_TABLE(Battle, wxEvtHandler)
     EVT_TIMER(TIMER_ID, Battle::OnTimer)
 END_EVENT_TABLE()
 
 Battle::Battle( IServer& serv, int id ) :
+		m_auto_unspec(false),
+		m_auto_unspec_num_players(0),
 		m_serv(serv),
         m_ah(*this),
         m_autolock_on_start(false),
@@ -74,7 +76,7 @@ void Battle::SendHostInfo( const std::string& Tag )
 
 void Battle::Update( const std::string& Tag )
 {
-	BattleEvents::GetBattleEventSender( BattleEvents::BattleInfoUpdate ).SendEvent( std::make_pair(this,TowxString(Tag)) );
+	BattleEvents::GetBattleEventSender( BattleEvents::BattleInfoUpdate ).SendEvent( std::make_pair(this,Tag));
 }
 
 
@@ -97,11 +99,10 @@ void Battle::OnRequestBattleStatus()
     bs.team = GetFreeTeam( true );
     bs.ally = GetFreeAlly( true );
     bs.spectator = false;
-    bs.colour = sett().GetBattleLastColour();
+	const wxColor col = sett().GetBattleLastColour();
+    bs.colour = LSL::lslColor(col.Red(), col.Green(), col.Blue());
+    //FIXME ? bs.colour = GetFreeColour( GetMe() );
     bs.side = sett().GetBattleLastSideSel( TowxString(GetHostModName()));
-    // theres some highly annoying bug with color changes on player join/leave.
-    if ( !bs.colour.IsOk() ) bs.colour = GetFreeColour( GetMe() );
-
     SendMyBattleStatus();
 }
 
@@ -166,7 +167,7 @@ void Battle::SaveMapDefaults()
 {
     // save map preset
         const wxString mapname = TowxString(LoadMap().name);
-        const std::string startpostype = CustomBattleOptions().getSingleValue( "startpostype", LSL::OptionsWrapper::EngineOption );
+        const std::string startpostype = CustomBattleOptions().getSingleValue( "startpostype", LSL::Enum::EngineOption );
         sett().SetMapLastStartPosType( mapname, TowxString(startpostype));
 		std::vector<Settings::SettStartBox> rects;
 		for( unsigned int i = 0; i <= GetLastRectIdx(); ++i )
@@ -190,8 +191,8 @@ void Battle::LoadMapDefaults( const std::string& mapname )
 {
     CustomBattleOptions().setSingleOption( "startpostype",
                                            STD_STRING(sett().GetMapLastStartPosType(TowxString(mapname))),
-                                           LSL::OptionsWrapper::EngineOption );
-	SendHostInfo( wxFormat( _T("%d_startpostype") ) % LSL::OptionsWrapper::EngineOption );
+                                           LSL::Enum::EngineOption );
+	SendHostInfo( wxFormat( _T("%d_startpostype") ) % LSL::Enum::EngineOption );
 
 	for( unsigned int i = 0; i <= GetLastRectIdx(); ++i ) if ( GetStartRect( i ).IsOk() ) RemoveStartRect(i); // remove all rects
 	SendHostInfo( IBattle::HI_StartRects );
@@ -212,6 +213,7 @@ User& Battle::OnUserAdded( User& user )
 			 m_timer = new wxTimer(this,TIMER_ID);
 			 m_timer->Start( TIMER_INTERVAL );
 		}
+
     user.SetBattle( this );
     user.BattleStatus().isfromdemo = false;
 
@@ -529,10 +531,10 @@ void Battle::ForceAlly( User& user, int ally )
 }
 
 
-void Battle::ForceColour( User& user, const wxColour& col )
+void Battle::ForceColour( User& user, const LSL::lslColor& col )
 {
-		IBattle::ForceColour( user, col );
-    m_serv.ForceColour( m_opts.battleid, user, col );
+	IBattle::ForceColour( user, col );
+	m_serv.ForceColour( m_opts.battleid, user, col );
 }
 
 
@@ -670,7 +672,7 @@ void Battle::StartSpring()
 void Battle::OnTimer( wxTimerEvent&  )
 {
 	if ( !IsFounderMe() ) return;
-	if ( m_ingame ) return;
+	if ( IBattle::GetInGame() ) return;
 	int autospect_trigger_time = sett().GetBattleLastAutoSpectTime();
 	if ( autospect_trigger_time == 0 ) return;
 	time_t now = time(0);
@@ -695,7 +697,7 @@ void Battle::OnTimer( wxTimerEvent&  )
 void Battle::SetInGame( bool value )
 {
 	time_t now = time(0);
-	if ( m_ingame && !value )
+	if ( IBattle::GetInGame() && !value )
 	{
 		for ( int i = 0; i < long(GetNumUsers()); i++ )
 		{
@@ -714,10 +716,10 @@ void Battle::SetInGame( bool value )
 void Battle::FixColours()
 {
     if ( !IsFounderMe() )return;
-    std::vector<wxColour> &palette = GetFixColoursPalette( m_teams_sizes.size() + 1 );
+    std::vector<LSL::lslColor> &palette = GetFixColoursPalette( m_teams_sizes.size() + 1 );
     std::vector<int> palette_use( palette.size(), 0 );
 
-    wxColour my_col = GetMe().BattleStatus().colour; // Never changes color of founder (me) :-)
+    LSL::lslColor my_col = GetMe().BattleStatus().colour; // Never changes color of founder (me) :-)
     int my_diff = 0;
     int my_col_i = GetClosestFixColour( my_col, palette_use,my_diff );
     palette_use[my_col_i]++;
@@ -732,7 +734,7 @@ void Battle::FixColours()
         if ( parsed_teams.find( status.team ) != parsed_teams.end() ) continue; // skip duplicates
         parsed_teams.insert( status.team );
 
-        wxColour &user_col=status.colour;
+        LSL::lslColor &user_col=status.colour;
         int user_col_i=GetClosestFixColour(user_col,palette_use, 60);
         palette_use[user_col_i]++;
 				for ( user_map_t::size_type j = 0; j < GetNumUsers(); j++ )
@@ -1007,7 +1009,7 @@ void Battle::FixTeamIDs( BalanceType balance_type, bool support_clans, bool stro
 
 	if ( numcontrolteams == 0 || numcontrolteams == -1 ) numcontrolteams = GetNumUsers() - GetSpectators(); // 0 or -1 -> use num players, will use comshare only if no available team slots
     IBattle::StartType position_type = (IBattle::StartType)
-            LSL::Util::FromString<long>(CustomBattleOptions().getSingleValue("startpostype", LSL::OptionsWrapper::EngineOption));
+            LSL::Util::FromString<long>(CustomBattleOptions().getSingleValue("startpostype", LSL::Enum::EngineOption));
     if ( ( position_type == ST_Fixed ) || ( position_type == ST_Random ) ) // if fixed start pos type or random, use max teams = start pos count
     {
       try
