@@ -5,17 +5,11 @@
 
 
 #include <wx/setup.h>
-#if wxUSE_DEBUGREPORT && defined(ENABLE_DEBUG_REPORT)
-
 #include <wx/debugrpt.h>
-#include "utils/platform.h"
-
-#include <sstream>
 #include <wx/arrstr.h>
 
-#if ! wxUSE_STACKWALKER && __WXMSW__
-	#include <windows.h>
-#endif
+#include "utils/platform.h"
+#include <sstream>
 
 //! @brief uploads zipped stacktraces using curl
 class NetDebugReport : public wxDebugReportCompress
@@ -26,7 +20,7 @@ class NetDebugReport : public wxDebugReportCompress
 	  //! the real workhorse
       bool Process();
 
-  protected:
+private:
       //! @brief gets called after server answered to the upload attempt
       bool OnServerReply(const wxArrayString& reply);
 	  const char* m_url;
@@ -35,7 +29,7 @@ class NetDebugReport : public wxDebugReportCompress
 class SpringDebugReport : public NetDebugReport {
 	public:
 		SpringDebugReport();
-protected:
+private:
 		void AddVFSFile( const wxString& fn, const wxString& id );
 
 };
@@ -50,22 +44,13 @@ class CrashReport
       static CrashReport c;
       return c;
     }
-
-    #if wxUSE_STACKWALKER && !__WXMSW__
         void GenerateReport();
-    #else
-        void GenerateReport(EXCEPTION_POINTERS* p);
-    #endif
-
         //! @brief is the container for the stream logging target
         std::ostringstream crashlog;
 
-    protected:
+private:
         CrashReport(){}
 
 };
 
-
-#endif //wxUSE_DEBUGREPORT && defined(ENABLE_DEBUG_REPORT)
-
 #endif // SPRINGLOBBY_HEADERGUARD_CRASHREPORT_H_INCLUDED
