@@ -98,7 +98,7 @@ bool CHttpDownloader::search(std::list<IDownload*>& res, const std::string& name
 			LOG_ERROR("Unknown Category %s", category.c_str());
 		filename+=PATH_DELIMITER;
 		if ((resfile["mirrors"].getType()!=XmlRpc::XmlRpcValue::TypeArray) ||
-		    (resfile["filename"].getType()!=XmlRpc::XmlRpcValue::TypeString)) {
+			(resfile["filename"].getType()!=XmlRpc::XmlRpcValue::TypeString)) {
 			LOG_ERROR("Invalid type in result");
 			return false;
 		}
@@ -153,12 +153,8 @@ size_t multi_write_data(void *ptr, size_t size, size_t nmemb, DownloadData* data
 	if ( data->download->write_only_from != NULL && data->download->write_only_from != data )
 		return size*nmemb;
 	else if ( data->download->write_only_from != NULL ) {
-		data->download->http_downloaded_size += size*nmemb;
-// 	    LOG_DEBUG("Downloaded %d",data->download->http_downloaded_size);
 		return data->download->file->Write((const char*)ptr, size*nmemb, 0);
 	}
-	data->download->http_downloaded_size += size*nmemb;
-// 	LOG_DEBUG("Downloaded %d",data->download->http_downloaded_size);
 	return data->download->file->Write((const char*)ptr, size*nmemb, data->start_piece);
 }
 
@@ -255,6 +251,15 @@ std::vector< unsigned int > CHttpDownloader::verifyAndGetNextPieces(CFile& file,
 	return pieces;
 }
 
+static int progress_func(DownloadData* data, double total, double done, double, double)
+{
+	data->download->progress = done;
+	if (data->got_ranges) {
+		LOG_PROGRESS(done, total, done >= total);
+	}
+	return 0;
+}
+
 bool CHttpDownloader::setupDownload(DownloadData* piece)
 {
 	std::vector<unsigned int> pieces = verifyAndGetNextPieces(*(piece->download->file), piece->download);
@@ -284,7 +289,9 @@ bool CHttpDownloader::setupDownload(DownloadData* piece)
 	piece->mirror->escapeUrl(escaped);
 	curl_easy_setopt(curle, CURLOPT_WRITEFUNCTION, multi_write_data);
 	curl_easy_setopt(curle, CURLOPT_WRITEDATA, piece);
-	curl_easy_setopt(curle, CURLOPT_NOPROGRESS, 1L);
+	curl_easy_setopt(curle, CURLOPT_NOPROGRESS, 0L);
+	curl_easy_setopt(curle, CURLOPT_PROGRESSDATA, piece);
+	curl_easy_setopt(curle, CURLOPT_PROGRESSFUNCTION, progress_func);
 	curl_easy_setopt(curle, CURLOPT_URL, escaped.c_str());
 
 	if ((piece->download->size>0) && (piece->start_piece>=0) && piece->download->pieces.size() > 0) { //don't set range, if size unknown
@@ -367,7 +374,6 @@ bool CHttpDownloader::processMessages(CURLM* curlm, std::vector <DownloadData*>&
 						// LOG("piece %d verified!", data->piece);
 					} else { // piece download broken, mark mirror as broken (for this file)
 						data->download->pieces[*it].state=IDownload::STATE_NONE;
-						data->download->http_downloaded_size -= data->download->piecesize;
 						data->mirror->status=Mirror::STATUS_BROKEN;
 						//FIXME: cleanup curl handle here + process next dl
 						LOG_ERROR("Piece %d is invalid",*it);
