@@ -6,11 +6,11 @@
 #include "lib/src/Downloader/IDownloader.h"
 #include "lib/src/FileSystem/FileSystem.h"
 #include "lib/src/FileSystem/File.h"
-#include "../utils/uievents.h"
-#include "../utils/conversion.h"
-#include "../utils/globalevents.h"
-#include "../utils/slpaths.h"
-#include "../mainwindow.h"
+#include "utils/uievents.h"
+#include "utils/conversion.h"
+#include "utils/globalevents.h"
+#include "utils/slpaths.h"
+#include "gui/mainwindow.h"
 #include "downloadsobserver.h"
 #include <list>
 
@@ -18,6 +18,11 @@
 #include <lslunitsync/unitsync.h>
 #include <lslutils/thread.h>
 #include <settings.h>
+#include "utils/slconfig.h"
+
+
+SLCONFIG("/Spring/PortableDownload", false, "true to download portable versions of spring, if false cache/settings/etc are shared (bogous!)");
+SLCONFIG("/Spring/RapidMasterUrl", "http://repos.springrts.com/repos.gz", "master url for rapid downloads");
 
 std::string PrDownloader::GetEngineCat()
 {
@@ -48,6 +53,8 @@ public:
 			d += TowxString(m_item.front()->name);
 			m_loader->download( m_item, sett().GetHTTPMaxParallelDownloads() );
 			std::list<IDownload*>::iterator it;
+			bool reload = false;
+			bool lobbydl = false;
 			for( it = m_item.begin(); it!=m_item.end(); ++it) {
 				IDownload* dl = *it;
 				switch(dl->cat) {
@@ -60,27 +67,40 @@ public:
 					SlPaths::SetUsedSpringIndex(dl->version);
 					break;
 				}
+				case IDownload::CAT_LOBBYCLIENTS:
+					lobbydl = true;
+					fileSystem->extract(dl->name, SlPaths::GetUpdateDir(), true);
+					break;
+				case IDownload::CAT_MAPS:
+				case IDownload::CAT_GAMES:
+					reload = true;
+					break;
 				default:
-					continue;
+					break;;
 				}
 			}
 			m_loader->freeResult( m_item );
 			UiEvents::ScopedStatusMessage msgcomplete(d, 0);
-			LSL::usync().ReloadUnitSyncLib();
-			// prefetch map data after a download as well
-			for( it = m_item.begin(); it!=m_item.end(); ++it) {
-				IDownload* dl = *it;
-				switch(dl->cat) {
-					case IDownload::CAT_MAPS: {
-						LSL::usync().PrefetchMap(dl->name); //FIXME: do the same for games, too
+			if (reload) {
+				LSL::usync().ReloadUnitSyncLib();
+				// prefetch map data after a download as well
+				for( it = m_item.begin(); it!=m_item.end(); ++it) {
+					IDownload* dl = *it;
+					switch(dl->cat) {
+						case IDownload::CAT_MAPS: {
+							LSL::usync().PrefetchMap(dl->name); //FIXME: do the same for games, too
+						}
+						default:
+							continue;
 					}
-					default:
-						continue;
 				}
-			}
 
-			//notify about finished download
-			GlobalEvent::Send(GlobalEvent::OnUnitsyncReloaded);
+				//notify about finished download
+				GlobalEvent::Send(GlobalEvent::OnUnitsyncReloaded);
+			}
+			if (lobbydl) {
+				GlobalEvent::Send(GlobalEvent::OnLobbyDownloaded);
+			}
 		}
 	}
 
@@ -111,6 +131,7 @@ SearchItem::SearchItem(std::list<IDownloader*> loaders, const std::string name,
 
 void SearchItem::Run()
 {
+	rapidDownload->setOption("forceupdate", "");
 	std::list<IDownload*> results;
 	std::list<IDownloader*>::const_iterator it = m_loaders.begin();
 	for( ; it != m_loaders.end(); ++it ) {
@@ -154,7 +175,8 @@ void PrDownloader::ClearFinished()
 void PrDownloader::UpdateSettings()
 {
 	fileSystem->setWritePath(SlPaths::GetDownloadDir());
-	rapidDownload->setOption("masterurl", "http://repos.springrts.com/repos.gz");
+	fileSystem->setEnginePortableDownload(cfg().ReadBool(_T("/Spring/PortableDownload")));
+	rapidDownload->setOption("masterurl", STD_STRING(cfg().ReadString(_T("/Spring/RapidMasterUrl"))));
 }
 
 void PrDownloader::RemoveTorrentByName(const std::string &/*name*/)
@@ -180,6 +202,23 @@ int PrDownloader::GetDownload(const std::string& category, const std::string &na
 	return -1;
 }
 
+bool PrDownloader::Download(const std::string& filename, const std::string& url)
+{
+	assert(!filename.empty());
+	assert(!url.empty());
+	std::list<IDownload*> results;
+	IDownload* dl = new IDownload();
+	dl->addMirror(url);
+	dl->name = filename;
+	dl->cat = IDownload::CAT_LOBBYCLIENTS;
+
+	results.push_back(dl);
+	DownloadItem* dl_item = new DownloadItem(results, httpDownload);
+	m_dl_thread->DoWork(dl_item);
+	return true;
+}
+
+
 void PrDownloader::OnSpringStarted(wxCommandEvent& /*data*/)
 {
 	//FIXME: pause downloads
