@@ -10,7 +10,7 @@
 #include <wx/protocol/http.h>
 #include <wx/sstream.h>
 #include <wx/thread.h>
-#include "../json/wx/jsonreader.h"
+#include "json/wx/jsonreader.h"
 #include "ui.h"
 #include <lslunitsync/unitsync.h>
 
@@ -85,7 +85,7 @@ void* SearchThread::Entry()
 	wxDELETE(httpStream);
 	wxCommandEvent notify(SEARCH_FINISHED,ContentDownloadDialog::ID_SEARCH_FINISHED);
 	notify.SetInt(0);
-	notify.SetString(res);
+	notify.SetString(res); //FIXME: wxWidgets strings in events are not threadsafe, this will crash, etc.etc
 	wxPostEvent(m_content_dialog,notify);
 //   std::cout << "Search finished" << std::endl;
 	return NULL;
@@ -161,7 +161,9 @@ void ContentDownloadDialog::OnSearch(wxCommandEvent& /*event*/)
 }
 void ContentDownloadDialog::OnSearchCompleted(wxCommandEvent& event)
 {
-	wxString json = event.GetString();
+	assert(wxThread::IsMain());
+
+	wxString json = event.GetString(); //FIXME: strings are not threadsafe in events, this is a bug / leads to crashes / mem-corruption, etc.ect.!!!!
 //   std::cout << json.ToAscii().data() << std::endl;
 
 	wxJSONReader reader;
@@ -170,7 +172,7 @@ void ContentDownloadDialog::OnSearchCompleted(wxCommandEvent& event)
 	m_search_thread = NULL;
 	m_searchbutton->Enable(true);
 	if ( errors ) {
-		wxMessageBox(_("Failed to parse search results"),_("Error"));
+		wxMessageBox(wxFormat("Failed to parse search results:\n%s") % json.c_str() ,_("Error"));
 		return;
 	}
 	const wxJSONInternalArray * a = root.AsArray();
@@ -189,7 +191,13 @@ void ContentDownloadDialog::OnSearchCompleted(wxCommandEvent& event)
 	for ( unsigned i = 0; i < a->GetCount(); i++ ) {
 		wxJSONValue val = a->Item(i);
 		wxString category = val[_("category")].AsString();
-		int size = val[_("size")].AsInt();
+
+		long size = 0;
+		if (val[_("size")].IsInt()) {
+			size = val[_("size")].AsInt();
+		} else if (val[_("size")].IsLong()){
+			size = val[_("size")].AsLong();
+		}
 		wxString name = val[_("springname")].AsString();
 //     std::cout << category.ToAscii().data() << "," << name.ToAscii().data() << "," << size << std::endl;
 		ContentSearchResult* res = new ContentSearchResult();
