@@ -4,7 +4,7 @@
 #define SPRINGLOBBY_HEADERGUARD_STATUSBAR_H
 
 #include <wx/statusbr.h>
-#include "../utils/uievents.h"
+#include "utils/uievents.h"
 
 class TaskBar;
 
@@ -16,13 +16,12 @@ public:
 	void OnAddMessage	( UiEvents::StatusData data );
 	void OnRemoveMessage( UiEvents::StatusData data );
 
-protected:
+private:
 	static const wxEventType UpdateMsgEvt;
 	void OnUpdateMsg(wxCommandEvent& evt);
 	EventReceiverFunc< Statusbar, UiEvents::StatusData, &Statusbar::OnAddMessage> m_addMessageSink;
 	EventReceiverFunc< Statusbar, UiEvents::StatusData, &Statusbar::OnRemoveMessage> m_removeMessageSink;
 
-private:
 	TaskBar* taskBar;
 	DECLARE_EVENT_TABLE()
 };
