@@ -12,7 +12,7 @@ class ToasterNotification : public INotification
 		ToasterNotification(wxWindow* parent);
 		virtual ~ToasterNotification();
 		virtual void Show(const wxBitmap& icon, const size_t pos, const UiEvents::NotficationData& data );
-	protected:
+private:
 		void SetPopupPosition( const size_t pos );
 		ToasterBox* m_toasterbox;
 		int m_width,m_height,m_x_offset,m_y_offset;
