@@ -15,7 +15,6 @@ lsl/battle/ibattle.cpp
 
 
 #include <wx/tokenzr.h>
-#include <wx/image.h>
 #include <wx/log.h>
 
 #include <list>
@@ -26,30 +25,29 @@ lsl/battle/ibattle.cpp
 
 #include <lslunitsync/unitsync.h>
 
+#include "lslutils/globalsmanager.h"
 #include "ibattle.h"
 #include "utils/conversion.h"
-#include "uiutils.h"
+#include "gui/uiutils.h"
 #include "settings.h"
-#include "ui.h" //only required for preset stuff
+#include "gui/ui.h"
 #include "spring.h"
 #include "springlobbyapp.h"
 #include "iserver.h"
 #include "serverselector.h"
 #include "log.h"
+#include "utils/lslconversion.h"
 
 
 IBattle::IBattle():
+	m_generating_script(false),
+	m_is_self_in(false),
+	m_ingame(false),
 	m_map_loaded(false),
 	m_mod_loaded(false),
-	m_previous_local_mod_name( "" ),
-	m_ingame(false),
-	m_auto_unspec(false),
-	m_auto_unspec_num_players(0),
-	m_generating_script(false),
 	m_players_ready(0),
 	m_players_sync(0),
 	m_players_ok(0),
-	m_is_self_in(false),
 	m_start_time(0)
 {
 }
@@ -57,7 +55,11 @@ IBattle::IBattle():
 
 IBattle::~IBattle()
 {
-	if ( m_is_self_in ) LSL::usync().UnSetCurrentMod();
+	try {
+		if ( m_is_self_in ) LSL::usync().UnSetCurrentMod();
+	} catch (const LSL::Util::GlobalDestroyedError& err) {
+		/* If this is called during TAServer::~TAServer, then unitsync might be unavailable. */
+	}
 }
 
 bool IBattle::IsSynced()
@@ -79,15 +81,15 @@ bool IBattle::IsSynced()
 	return synced;
 }
 
-std::vector<wxColour> &IBattle::GetFixColoursPalette( int numteams ) const
+std::vector<LSL::lslColor> &IBattle::GetFixColoursPalette( int numteams ) const
 {
 	return GetBigFixColoursPalette( numteams );
 }
 
-wxColour IBattle::GetFixColour(int i) const
+LSL::lslColor IBattle::GetFixColour(int i) const
 {
 	int size = m_teams_sizes.size();
-	std::vector<wxColour> palette = GetFixColoursPalette( size );
+	std::vector<LSL::lslColor> palette = GetFixColoursPalette( size );
 	return palette[i];
 }
 
@@ -102,8 +104,8 @@ int IBattle::GetPlayerNum( const User& user ) const
 
 class DismissColor
 {
-protected:
-	typedef std::vector<wxColour>
+private:
+	typedef std::vector<LSL::lslColor>
 	ColorVec;
 	const ColorVec& m_other;
 
@@ -112,7 +114,7 @@ public:
 		: m_other( other )
 	{}
 
-	bool operator() ( wxColor to_check ) {
+	bool operator() ( LSL::lslColor to_check ) {
 		return std::find ( m_other.begin(), m_other.end(), to_check ) != m_other.end();
 	}
 };
@@ -126,14 +128,14 @@ public:
 		: m_mindiff ( mindiff )
 	{}
 
-	bool operator() ( wxColor a, wxColor b ) {
+	bool operator() ( LSL::lslColor a, LSL::lslColor b ) {
 		return AreColoursSimilar( a, b, m_mindiff );
 	}
 };
 
-wxColour IBattle::GetFreeColour( User * ) const
+LSL::lslColor IBattle::GetFreeColour( User * ) const
 {
-	typedef std::vector<wxColour>
+	typedef std::vector<LSL::lslColor>
 	ColorVec;
 
 	ColorVec current_used_colors;
@@ -155,18 +157,18 @@ wxColour IBattle::GetFreeColour( User * ) const
 	}
 }
 
-wxColour IBattle::GetFreeColour( User &for_whom ) const
+LSL::lslColor IBattle::GetFreeColour( User &for_whom ) const
 {
 	return GetFreeColour( &for_whom );
 }
 
 
-wxColour IBattle::GetNewColour() const
+LSL::lslColor IBattle::GetNewColour() const
 {
 	return GetFreeColour();
 }
 
-int IBattle::ColourDifference(const wxColour &a, const wxColour &b)  const// returns max difference of r,g,b.
+int IBattle::ColourDifference(const LSL::lslColor &a, const LSL::lslColor &b)  const// returns max difference of r,g,b.
 {
 	return std::max(abs(a.Red()-b.Red()),std::max(abs(a.Green()-b.Green()),abs(a.Blue()-b.Blue())));
 
@@ -191,9 +193,9 @@ int IBattle::GetFreeTeam( bool excludeme ) const
 	return lowest;
 }
 
-int IBattle::GetClosestFixColour(const wxColour &col, const std::vector<int> &excludes, int difference) const
+int IBattle::GetClosestFixColour(const LSL::lslColor &col, const std::vector<int> &excludes, int difference) const
 {
-	std::vector<wxColour> palette = GetFixColoursPalette( m_teams_sizes.size() + 1 );
+	std::vector<LSL::lslColor> palette = GetFixColoursPalette( m_teams_sizes.size() + 1 );
 	int result=0;
 	int t1=palette.size();
 	int t2=excludes.size();
@@ -518,7 +520,7 @@ void IBattle::ForceAlly( User& user, int ally )
 }
 
 
-void IBattle::ForceColour( User& user, const wxColour& col )
+void IBattle::ForceColour( User& user, const LSL::lslColor& col )
 {
 	if ( IsFounderMe() || user.BattleStatus().IsBot() ) {
 		user.BattleStatus().colour = col;
@@ -687,7 +689,7 @@ const LSL::UnitsyncMap& IBattle::LoadMap()
 		try {
 			ASSERT_EXCEPTION( MapExists(), _T("Map does not exist: ") + TowxString(m_host_map.name) );
 			m_local_map = LSL::usync().GetMap( m_host_map.name );
-			bool options_loaded = CustomBattleOptions().loadOptions( LSL::OptionsWrapper::MapOption, m_host_map.name );
+			bool options_loaded = CustomBattleOptions().loadOptions( LSL::Enum::MapOption, m_host_map.name );
 			ASSERT_EXCEPTION( options_loaded, _T("couldn't load the map options") );
 			m_map_loaded = true;
 
@@ -738,7 +740,7 @@ const LSL::UnitsyncMod& IBattle::LoadMod()
 		try {
 			ASSERT_EXCEPTION( ModExists(), _T("Mod does not exist.") );
 			m_local_mod = LSL::usync().GetMod( m_host_mod.name );
-			bool options_loaded = CustomBattleOptions().loadOptions( LSL::OptionsWrapper::ModOption, m_host_mod.name );
+			bool options_loaded = CustomBattleOptions().loadOptions( LSL::Enum::ModOption, m_host_mod.name );
 			ASSERT_EXCEPTION( options_loaded, _T("couldn't load the mod options") );
 			m_mod_loaded = true;
 		} catch (...) {}
@@ -759,15 +761,20 @@ std::string IBattle::GetHostModHash() const
 }
 
 
-bool IBattle::MapExists() const
+bool IBattle::MapExists(bool comparehash) const
 {
-	return LSL::usync().MapExists( m_host_map.name, m_host_map.hash );
+	if (comparehash) {
+		return LSL::usync().MapExists( m_host_map.name, m_host_map.hash );
+	}
+	return LSL::usync().MapExists( m_host_map.name, "");
 }
 
 
-bool IBattle::ModExists() const
+bool IBattle::ModExists(bool comparehash) const
 {
-	return LSL::usync().ModExists( m_host_mod.name, m_host_mod.hash );
+	if (comparehash)
+		return LSL::usync().ModExists( m_host_mod.name, m_host_mod.hash );
+	return LSL::usync().ModExists( m_host_mod.name, "");
 }
 
 void IBattle::RestrictUnit( const std::string& unitname, int count )
@@ -834,14 +841,14 @@ bool IBattle::LoadOptionsPreset( const std::string& name )
 	if (preset.empty()) return false; //preset not found
 	m_preset = preset;
 
-	for ( unsigned int i = 0; i < LSL::OptionsWrapper::LastOption; i++) {
+	for ( unsigned int i = 0; i < LSL::Enum::LastOption; i++) {
 		std::map<wxString,wxString> options = sett().GetHostingPreset( TowxString(m_preset), i );
-		if ( (LSL::OptionsWrapper::GameOption)i != LSL::OptionsWrapper::PrivateOptions ) {
+		if ( (LSL::Enum::GameOption)i != LSL::Enum::PrivateOptions ) {
 			for ( std::map<wxString,wxString>::const_iterator itor = options.begin(); itor != options.end(); ++itor ) {
 				wxLogWarning( itor->first + _T(" ::: ") + itor->second );
 				CustomBattleOptions().setSingleOption( STD_STRING(itor->first),
 								       STD_STRING(itor->second),
-								       (LSL::OptionsWrapper::GameOption)i );
+								       (LSL::Enum::GameOption)i );
 			}
 		} else {
 			if ( !options[_T("mapname")].IsEmpty() ) {
@@ -876,7 +883,7 @@ bool IBattle::LoadOptionsPreset( const std::string& name )
 				RestrictUnit( STD_STRING(unitinfo.BeforeLast(_T('='))), s2l( unitinfo.AfterLast(_T('=')) ) );
 			}
 			SendHostInfo( HI_Restrictions );
-			Update( wxFormat( _T("%d_restrictions") ) % LSL::OptionsWrapper::PrivateOptions );
+			Update( wxFormat( _T("%d_restrictions") ) % LSL::Enum::PrivateOptions );
 
 		}
 	}
@@ -891,19 +898,19 @@ void IBattle::SaveOptionsPreset( const std::string& name )
 	m_preset = FixPresetName(name);
 	if (m_preset == "") m_preset = name; //new preset
 
-	for ( int i = 0; i < (int)LSL::OptionsWrapper::LastOption; i++) {
-		if ( (LSL::OptionsWrapper::GameOption)i != LSL::OptionsWrapper::PrivateOptions ) {
-			const auto opts = CustomBattleOptions().getOptionsMap( (LSL::OptionsWrapper::GameOption)i );
+	for ( int i = 0; i < (int)LSL::Enum::LastOption; i++) {
+		if ( (LSL::Enum::GameOption)i != LSL::Enum::PrivateOptions ) {
+			const auto opts = CustomBattleOptions().getOptionsMap( (LSL::Enum::GameOption)i );
 			std::map<wxString, wxString> wopts;
 for( const auto pair : opts)
 				wopts.insert(std::make_pair(TowxString(pair.first), TowxString(pair.second)));
-			sett().SetHostingPreset( TowxString(m_preset), (LSL::OptionsWrapper::GameOption)i, wopts);
+			sett().SetHostingPreset( TowxString(m_preset), (LSL::Enum::GameOption)i, wopts);
 		} else {
 			std::map<wxString,wxString> opts;
 			opts[_T("mapname")] = TowxString(GetHostMapName());
 			unsigned int validrectcount = 0;
 			if ( LSL::Util::FromString<long>(
-				     CustomBattleOptions().getSingleValue("startpostype", LSL::OptionsWrapper::EngineOption ) ) == ST_Choose ) {
+				     CustomBattleOptions().getSingleValue("startpostype", LSL::Enum::EngineOption ) ) == ST_Choose ) {
 				unsigned int boxcount = GetLastRectIdx();
 				for ( unsigned int boxnum = 0; boxnum <= boxcount; boxnum++ ) {
 					BattleStartRect rect = GetStartRect( boxnum );
@@ -925,7 +932,7 @@ for( const auto pair : opts)
 			}
 			opts[_T("restrictions")] = restrictionsstring;
 
-			sett().SetHostingPreset( TowxString(m_preset), (LSL::OptionsWrapper::GameOption)i, opts );
+			sett().SetHostingPreset( TowxString(m_preset), (LSL::Enum::GameOption)i, opts );
 		}
 	}
 	sett().SaveSettings();
@@ -947,9 +954,9 @@ void IBattle::DeletePreset( const std::string & name )
 	ui().ReloadPresetList();
 }
 
-wxArrayString IBattle::GetPresetList()
+LSL::StringVector IBattle::GetPresetList()
 {
-	return sett().GetPresetList();
+	return wxArrayStringToLSL(sett().GetPresetList());
 }
 
 void IBattle::UserPositionChanged( const User& /*unused*/ )
@@ -1017,8 +1024,8 @@ void IBattle::LoadScriptMMOpts( const LSL::TDF::PDataList& node )
 {
 	if ( !node.ok() ) return;
 	LSL::OptionsWrapper& opts = CustomBattleOptions();
-	auto options = opts.getOptionsMap(LSL::OptionsWrapper::EngineOption);
-for (const auto i : options) {
+	auto options = opts.getOptionsMap(LSL::Enum::EngineOption);
+	for (const auto i : options) {
 		opts.setSingleOption( i.first, node->GetString( i.first, i.second));
 	}
 }
@@ -1114,7 +1121,7 @@ void IBattle::GetBattleFromScript( bool loadmapmod )
 						teaminfos.StartPosX = team->GetInt("StartPosX", -1 );
 						teaminfos.StartPosY = team->GetInt("StartPosY", -1 );
 						teaminfos.AllyTeam = team->GetInt("AllyTeam", 0 );
-						teaminfos.RGBColor = GetColorFromFloatStrng(TowxString(team->GetString("RGBColor")));
+						teaminfos.RGBColor = LSL::Util::ColorFromFloatString(team->GetString("RGBColor"));
 						teaminfos.SideName = team->GetString("Side", "");
 						teaminfos.Handicap = team->GetInt("Handicap", 0 );
 						const int sidepos = LSL::Util::IndexInSequence(sides, teaminfos.SideName);
