@@ -113,7 +113,7 @@ struct BattleOptions {
 	bool guilistactiv;
 };
 
-class IBattle: public UserList, public SL::NonCopyable
+class IBattle: public UserList //, private SL::NonCopyable
 {
 public:
 
@@ -173,7 +173,7 @@ public:
 		int StartPosX;
 		int StartPosY;
 		int AllyTeam;
-		wxColor RGBColor;
+		LSL::lslColor RGBColor;
 		std::string SideName;
 		int Handicap;
 		int SideNum;
@@ -216,8 +216,8 @@ public:
 	virtual std::string GetHostModName() const;
 	virtual std::string GetHostModHash() const;
 
-	virtual bool MapExists() const;
-	virtual bool ModExists() const;
+	virtual bool MapExists(bool comparehash = true) const;
+	virtual bool ModExists(bool comparehash = true) const;
 
 	virtual BattleStartRect GetStartRect( unsigned int allyno ) const;
 	virtual User& OnUserAdded( User& user );
@@ -229,7 +229,7 @@ public:
 	virtual void ForceSide( User& user, int side );
 	virtual void ForceAlly( User& user, int ally );
 	virtual void ForceTeam( User& user, int team );
-	virtual void ForceColour( User& user, const wxColour& col );
+	virtual void ForceColour( User& user, const LSL::lslColor& col );
 	virtual void ForceSpectator( User& user, bool spectator );
 	virtual void SetHandicap( User& user, int handicap);
 	virtual void KickPlayer( User& user );
@@ -277,15 +277,15 @@ public:
 	virtual void SaveOptionsPreset( const std::string& name );
 	virtual std::string GetCurrentPreset();
 	virtual void DeletePreset( const std::string& name );
-	virtual wxArrayString GetPresetList();
+	virtual LSL::StringVector GetPresetList();
 
-	virtual std::vector<wxColour> &GetFixColoursPalette( int numteams ) const;
-	virtual int GetClosestFixColour(const wxColour &col, const std::vector<int> &excludes, int difference) const;
-	virtual wxColour GetFixColour(int i) const;
-	virtual wxColour GetFreeColour( User &for_whom ) const;
-	virtual wxColour GetFreeColour( User *for_whom = NULL ) const;
-	virtual wxColour GetNewColour() const;
-	virtual int ColourDifference(const wxColour &a, const wxColour &b)  const;
+	virtual std::vector<LSL::lslColor> &GetFixColoursPalette( int numteams ) const;
+	virtual int GetClosestFixColour(const LSL::lslColor &col, const std::vector<int> &excludes, int difference) const;
+	virtual LSL::lslColor GetFixColour(int i) const;
+	virtual LSL::lslColor GetFreeColour( User &for_whom ) const;
+	virtual LSL::lslColor GetFreeColour( User *for_whom = NULL ) const;
+	virtual LSL::lslColor GetNewColour() const;
+	virtual int ColourDifference(const LSL::lslColor &a, const LSL::lslColor &b)  const;
 
 	virtual User& GetFounder() const;
 
@@ -551,8 +551,17 @@ public:
 	virtual void RingNotSyncedPlayers() {}
 	virtual void RingNotSyncedAndNotReadyPlayers() {}
 	virtual void SetAutoLockOnStart(bool /*autolock*/) {}
-protected:
 
+protected:
+	BattleOptions m_opts;
+	bool m_generating_script;
+	std::map<int, int> m_teams_sizes; // controlteam -> number of people in
+	bool m_is_self_in;
+	std::map<std::string, time_t> m_ready_up_map; // player name -> time counting from join/unspect
+	std::string m_previous_local_mod_name;
+	LSL::UnitsyncMod m_local_mod;
+
+private:
 	void LoadScriptMMOpts( const std::string& sectionname, const LSL::TDF::PDataList& node );
 	void LoadScriptMMOpts( const LSL::TDF::PDataList& node );
 
@@ -561,40 +570,26 @@ protected:
 	void PlayerJoinedTeam( int team );
 	void PlayerJoinedAlly( int ally );
 
+	bool m_ingame;
 	bool m_map_loaded;
 	bool m_mod_loaded;
 	LSL::UnitsyncMap m_local_map;
-	LSL::UnitsyncMod m_local_mod;
 	LSL::UnitsyncMap m_host_map;
 	LSL::UnitsyncMod m_host_mod;
-	std::string m_previous_local_mod_name;
 
 	std::map<std::string, int> m_restricted_units;
 
 	LSL::OptionsWrapper m_opt_wrap;
 
-	BattleOptions m_opts;
-
-	bool m_ingame;
-
-	bool m_auto_unspec; // unspec as soon as there's a free slot
-	unsigned int m_auto_unspec_num_players; // number of players in the battle when m_auto_unspec was set to true
-
-	bool m_generating_script;
-
 	std::map<unsigned int,BattleStartRect> m_rects;
 
-	std::map<std::string, time_t> m_ready_up_map; // player name -> time counting from join/unspect
-
 	unsigned int m_players_ready;
 	unsigned int m_players_sync;
 	unsigned int m_players_ok; // players which are ready and in sync
-	std::map<int, int> m_teams_sizes; // controlteam -> number of people in
 	std::map<int, int> m_ally_sizes; // allyteam -> number of people in
 
 	std::string m_preset;
 
-	bool m_is_self_in;
 	UserVec m_internal_bot_list;
 
 	/// replay&savegame stuff
