@@ -16,21 +16,9 @@ public:
 	virtual void OnConnected( Socket& /*sock*/ ) {}
 	virtual void OnDisconnected( Socket& /*sock*/ ) {}
 	virtual void OnDataReceived( Socket& /*sock*/ ) {}
+	virtual void OnError(const wxString& /*error*/) {}
 	virtual void Ping() {}
 };
 
-class FakeNetClass : public iNetClass
-{
-public:
-
-	FakeNetClass() {}
-	~FakeNetClass() {}
-
-	void OnConnected( Socket& /*unused*/ ) {}
-	void OnDisconnected( Socket& /*unused*/ ) {}
-	void OnDataReceived( Socket& /*unused*/ ) {}
-	void Ping() {}
-};
-
 #endif // SPRINGLOBBY_HEADERGUARD_INETCLASS_H
 
