@@ -79,10 +79,8 @@ void Battle::OnRequestBattleStatus()
     bs.ally = GetFreeAlly( true );
     bs.spectator = false;
     bs.color = Util::config().GetBattleLastColor();
+	// FIXME? bs.color = Util::GetFreeColor( GetMe() );
     bs.side = Util::config().GetBattleLastSideSel( GetHostModName() );
-    // theres some highly annoying bug with color changes on player join/leave.
-	if ( !bs.color.IsOk() )
-		bs.color = Util::GetFreeColor( GetMe() );
     SendMyBattleStatus();
 }
 
@@ -138,7 +136,7 @@ void Battle::SaveMapDefaults()
 {
     // save map preset
     std::string mapname = LoadMap().name;
-	std::string startpostype = CustomBattleOptions()->getSingleValue( "startpostype", LSL::OptionsWrapper::EngineOption );
+	std::string startpostype = CustomBattleOptions()->getSingleValue( "startpostype", LSL::Enum::EngineOption );
     Util::config().SetMapLastStartPosType( mapname, startpostype);
     std::vector<LSL::Util::SettStartBox> rects;
     for( unsigned int i = 0; i <= GetLastRectIdx(); ++i )
@@ -160,8 +158,8 @@ void Battle::SaveMapDefaults()
 
 void Battle::LoadMapDefaults( const std::string& mapname )
 {
-	CustomBattleOptions()->setSingleOption( "startpostype", Util::config().GetMapLastStartPosType( mapname ), LSL::OptionsWrapper::EngineOption );
-	SendHostInfo( (boost::format( "%d_startpostype" ) % LSL::OptionsWrapper::EngineOption).str() );
+	CustomBattleOptions()->setSingleOption( "startpostype", Util::config().GetMapLastStartPosType( mapname ), LSL::Enum::EngineOption );
+	SendHostInfo( (boost::format( "%d_startpostype" ) % LSL::Enum::EngineOption).str() );
 
 	for( unsigned int i = 0; i <= GetLastRectIdx(); ++i ) {
 		if ( GetStartRect( i ).IsOk() )
@@ -682,7 +680,7 @@ void Battle::SetInGame( bool value )
 void Battle::FixColors()
 {
     if ( !IsFounderMe() )return;
-    std::vector<lslColor> &palette = GetFixColorsPalette( m_teams_sizes.size() + 1 );
+    std::vector<lslColor> palette = GetFixColorsPalette( m_teams_sizes.size() + 1 );
     std::vector<int> palette_use( palette.size(), 0 );
 
 	lslColor my_col = GetMe()->BattleStatus().color; // Never changes color of founder (me) :-)
@@ -968,7 +966,7 @@ void Battle::FixTeamIDs( Enum::BalanceType balance_type, bool support_clans, boo
 
     if ( numcontrolteams == 0 || numcontrolteams == -1 ) numcontrolteams = m_userlist.size() - GetSpectators(); // 0 or -1 -> use num players, will use comshare only if no available team slots
     Enum::StartType position_type = (Enum::StartType)
-            Util::FromString<long>( CustomBattleOptions()->getSingleValue( "startpostype", LSL::OptionsWrapper::EngineOption ) );
+            Util::FromString<long>( CustomBattleOptions()->getSingleValue( "startpostype", LSL::Enum::EngineOption ) );
     if ( ( position_type == Enum::ST_Fixed ) || ( position_type == Enum::ST_Random ) ) // if fixed start pos type or random, use max teams = start pos count
     {
         try
