@@ -25,6 +25,17 @@
 
 #define LOCK_UNITSYNC boost::mutex::scoped_lock lock_criticalsection(m_lock)
 
+#define ASYNC_LOAD 0
+#if ASYNC_LOAD
+#define TRY_LOCK(ret) \
+	boost::mutex::scoped_try_lock lock_criticalsection(m_lock); \
+	if (!lock_criticalsection.owns_lock()) { \
+		return ret; \
+	}
+#else
+#define TRY_LOCK(ret)
+#endif
+
 #define ASSERT_EXCEPTION(cond,msg) do { if (!(cond)) { LSL_THROW( unitsync, msg ); } } while (0)
 
 namespace LSL {
@@ -48,6 +59,7 @@ enum ASYNC_EVENTS {
 
 Unitsync::~Unitsync()
 {
+	ClearCache();
 	delete m_cache_thread;
 	m_cache_thread = NULL;
 }
@@ -71,6 +83,7 @@ bool CompareStringNoCase(const std::string& first, const std::string& second)
 bool Unitsync::LoadUnitSyncLib( const std::string& unitsyncloc )
 {
 	LOCK_UNITSYNC;
+	ClearCache();
 	bool ret = _LoadUnitSyncLib( unitsyncloc );
 	if (ret)
 	{
@@ -80,7 +93,7 @@ bool Unitsync::LoadUnitSyncLib( const std::string& unitsyncloc )
 	return ret;
 }
 
-void Unitsync::PopulateArchiveList()
+void Unitsync::ClearCache()
 {
 	m_maps_list.clear();
 	m_mods_list.clear();
@@ -94,6 +107,12 @@ void Unitsync::PopulateArchiveList()
 	m_mods_unchained_hash.clear();
 	m_shortname_to_name_map.clear();
 	m_sides_cache.Clear();
+	m_map_gameoptions.clear();
+	m_game_gameoptions.clear();
+}
+
+void Unitsync::PopulateArchiveList()
+{
 
 	int numMaps = susynclib().GetMapCount();
 	for ( int i = 0; i < numMaps; i++ )
@@ -198,11 +217,13 @@ std::string Unitsync::GetSpringVersion() const
 
 StringVector Unitsync::GetModList() const
 {
+	TRY_LOCK(StringVector())
 	return m_mod_array;
 }
 
 bool Unitsync::ModExists( const std::string& modname, const std::string& hash ) const
 {
+	TRY_LOCK(false)
 	LocalArchivesVector::const_iterator itor = m_mods_list.find(modname);
 	if ( itor == m_mods_list.end() ) return false;
 	if (hash.empty() || hash == "0") return true;
@@ -212,6 +233,7 @@ bool Unitsync::ModExists( const std::string& modname, const std::string& hash )
 UnitsyncMod Unitsync::GetMod( const std::string& modname )
 {
 	UnitsyncMod m;
+	TRY_LOCK(m);
 	m.name = modname;
 	m.hash = m_mods_list[modname];
 	return m;
@@ -221,6 +243,7 @@ UnitsyncMod Unitsync::GetMod( const std::string& modname )
 UnitsyncMod Unitsync::GetMod( int index )
 {
 	UnitsyncMod m;
+	TRY_LOCK(m);
 	m.name = m_mod_array[index];
 	m.hash = m_mods_list[m.name];
 	return m;
@@ -228,12 +251,14 @@ UnitsyncMod Unitsync::GetMod( int index )
 
 StringVector Unitsync::GetMapList() const
 {
+	TRY_LOCK(StringVector())
 	return m_map_array;
 }
 
 StringVector Unitsync::GetModValidMapList( const std::string& modname ) const
 {
     StringVector ret;
+	TRY_LOCK(ret)
 	try {
 		unsigned int mapcount = susynclib().GetValidMapCount( modname );
 		for ( unsigned int i = 0; i < mapcount; i++ )
@@ -244,6 +269,7 @@ StringVector Unitsync::GetModValidMapList( const std::string& modname ) const
 
 bool Unitsync::MapExists( const std::string& mapname, const std::string& hash ) const
 {
+	TRY_LOCK(false)
 	LocalArchivesVector::const_iterator itor = m_maps_list.find(mapname);
 	if ( itor == m_maps_list.end() ) return false;
 	if (hash.empty() || hash == "0") return true;
@@ -253,6 +279,7 @@ bool Unitsync::MapExists( const std::string& mapname, const std::string& hash )
 UnitsyncMap Unitsync::GetMap( int index )
 {
 	UnitsyncMap m;
+	TRY_LOCK(m)
 	if ( index < 0 )
 		return m;
 	m.name = m_map_array[index];
@@ -305,13 +332,20 @@ void GetOptionEntry(const int i, GameOptions& ret)
 
 GameOptions Unitsync::GetMapOptions( const std::string& name )
 {
-	assert(!name.empty());
 	GameOptions ret;
+	TRY_LOCK(ret)
+
+	assert(!name.empty());
+	if (m_map_gameoptions.find(name) != m_map_gameoptions.end()) {
+		return m_map_gameoptions[name];
+	}
+
 	int count = susynclib().GetMapOptionCount(name);
 	for (int i = 0; i < count; ++i)
 	{
 		GetOptionEntry( i, ret );
 	}
+	m_map_gameoptions[name] = ret;
 	return ret;
 }
 
@@ -345,11 +379,17 @@ GameOptions Unitsync::GetModOptions( const std::string& name )
 {
 	assert(!name.empty());
 	GameOptions ret;
+	TRY_LOCK(ret)
+	if (m_game_gameoptions.find(name) != m_game_gameoptions.end()) {
+		return m_game_gameoptions[name];
+	}
+	if(!IsLoaded()) return ret;
 	int count = susynclib().GetModOptionCount(name);
 	for (int i = 0; i < count; ++i)
 	{
 		GetOptionEntry(i, ret );
 	}
+	m_game_gameoptions[name] = ret;
 	return ret;
 }
 
@@ -357,6 +397,7 @@ StringVector Unitsync::GetModDeps( const std::string& modname ) const
 {
 	assert(!modname.empty());
 	StringVector ret;
+	TRY_LOCK(ret)
 	try
 	{
 		ret = susynclib().GetModDeps( Util::IndexInSequence( m_unsorted_mod_array, modname ) );
@@ -369,6 +410,7 @@ StringVector Unitsync::GetSides( const std::string& modname )
 {
 	assert(!modname.empty());
 	StringVector ret;
+	TRY_LOCK(ret);
 	const std::string cachefile = GetFileCachePath(modname, true ) + ".sides";
 	if (m_sides_cache.TryGet( cachefile, ret)) { //first return from mru cache
 		return ret;
@@ -393,6 +435,7 @@ UnitsyncImage Unitsync::GetSidePicture( const std::string& modname, const std::s
 
 	const std::string cachepath = GetFileCachePath( modname, true, false) +"-side-" +SideName + ".png";
 	UnitsyncImage img;
+	TRY_LOCK(img);
 
 	if (Util::FileExists(cachepath)) {
 		img = UnitsyncImage( cachepath );
@@ -436,6 +479,7 @@ UnitsyncImage Unitsync::GetImage( const std::string& modname, const std::string&
 StringVector Unitsync::GetAIList( const std::string& modname ) const
 {
 	StringVector ret;
+	TRY_LOCK(ret);
 	if (modname.empty()) return ret;
 	int total = susynclib().GetSkirmishAICount( modname );
 	for ( int i = 0; i < total; i++ ) {
@@ -452,6 +496,9 @@ StringVector Unitsync::GetAIList( const std::string& modname ) const
 
 void Unitsync::UnSetCurrentMod()
 {
+#if ASYNC_LOAD
+	LOCK_UNITSYNC;
+#endif
 	try
 	{
 		susynclib().UnSetCurrentMod();
@@ -461,6 +508,7 @@ void Unitsync::UnSetCurrentMod()
 StringVector Unitsync::GetAIInfos( int index ) const
 {
     StringVector ret;
+	TRY_LOCK(ret);
 	try
 	{
 		ret = susynclib().GetAIInfo( index );
@@ -473,6 +521,7 @@ GameOptions Unitsync::GetAIOptions( const std::string& modname, int index )
 {
 	assert(!modname.empty());
 	GameOptions ret;
+	TRY_LOCK(ret);
 	int count = susynclib().GetAIOptionCount(modname, index);
 	for (int i = 0; i < count; ++i)
 	{
@@ -486,6 +535,7 @@ StringVector Unitsync::GetUnitsList( const std::string& modname )
 	assert(!modname.empty());
 	const std::string cachefile = GetFileCachePath( modname, true ) + ".units";
 	StringVector cache;
+	TRY_LOCK(cache)
 
 	if (!GetCacheFile(cachefile, cache)) { //cache read failed
 		susynclib().SetCurrentMod( modname );
@@ -509,15 +559,18 @@ UnitsyncImage Unitsync::GetMinimap( const std::string& mapname )
 UnitsyncImage Unitsync::GetMinimap( const std::string& mapname, int width, int height )
 {
 	UnitsyncImage img;
-	if (mapname.empty())
+	TRY_LOCK(img)
+	if (mapname.empty()) {
 		return img;
-	const bool tiny = ( width <= 100 && height <= 100 );
-	if ( tiny && m_tiny_minimap_cache.TryGet( mapname, img ) )
-	{
-		lslSize image_size = lslSize(img.GetWidth(), img.GetHeight()).MakeFit( lslSize(width, height) );
-		if ( image_size.GetWidth() != img.GetWidth() || image_size.GetHeight() != img.GetHeight() )
-			img.Rescale( image_size.GetWidth(), image_size.GetHeight() );
+	}
 
+	const bool tiny = ( width <= 100 && height <= 100 );
+	if ( tiny && m_tiny_minimap_cache.TryGet( mapname, img ) ) {
+
+		lslSize image_size = lslSize(img.GetWidth(), img.GetHeight()).MakeFit( lslSize(width, height) );
+		if ( image_size.GetWidth() != img.GetWidth() || image_size.GetHeight() != img.GetHeight() ) {
+			img.Rescale( image_size.GetWidth(), image_size.GetHeight() );
+		}
 		return img;
 	}
 
@@ -548,6 +601,7 @@ UnitsyncImage Unitsync::GetMetalmap( const std::string& mapname )
 
 UnitsyncImage Unitsync::GetMetalmap( const std::string& mapname, int width, int height )
 {
+	TRY_LOCK(UnitsyncImage())
 	return _GetScaledMapImage( mapname, &Unitsync::GetMetalmap, width, height );
 }
 
@@ -558,14 +612,16 @@ UnitsyncImage Unitsync::GetHeightmap( const std::string& mapname )
 
 UnitsyncImage Unitsync::GetHeightmap( const std::string& mapname, int width, int height )
 {
+	TRY_LOCK(UnitsyncImage())
 	return _GetScaledMapImage( mapname, &Unitsync::GetHeightmap, width, height );
 }
 
 UnitsyncImage Unitsync::_GetMapImage( const std::string& mapname, const std::string& imagename, UnitsyncImage (UnitsyncLib::*loadMethod)(const std::string&) )
 {
 	UnitsyncImage img;
-	if ( m_map_image_cache.TryGet( mapname + imagename, img ) )
+	if ( m_map_image_cache.TryGet( mapname + imagename, img ) ) {
 		return img;
+	}
 
 	const std::string cachefile = GetFileCachePath( mapname, false, false) + imagename;
 	if (Util::FileExists(cachefile)) {
@@ -664,11 +720,13 @@ MapInfo Unitsync::_GetMapInfoEx( const std::string& mapname )
 
 bool Unitsync::ReloadUnitSyncLib()
 {
-	//FIXME: use async call
-	//LoadUnitSyncLibAsync(LSL::Util::config().GetCurrentUsedUnitSync().string());
+#if ASYNC_LOAD
+	LOCK_UNITSYNC;
+#endif
 	const std::string path = LSL::Util::config().GetCurrentUsedUnitSync();
 	if (path.empty())
 		return false;
+	//LoadUnitSyncLibAsync(path); //FIXME: repair/use this!
 	LoadUnitSyncLib(path);
 	return true;
 }
@@ -679,12 +737,16 @@ void Unitsync::SetSpringDataPath( const std::string& path )
 	if (!IsLoaded()) {
 		return;
 	}
+#if ASYNC_LOAD
+	LOCK_UNITSYNC;
+#endif
 
 	susynclib().SetSpringConfigString( "SpringData", path );
 }
 
 bool Unitsync::GetSpringDataPath(std::string& path)
 {
+	TRY_LOCK(false)
 	if (IsLoaded()) {
 		path = susynclib().GetSpringDataDir();
 	}
@@ -738,6 +800,7 @@ void Unitsync::SetCacheFile( const std::string& path, const StringVector& data )
 StringVector Unitsync::GetPlaybackList( bool ReplayType ) const
 {
 	StringVector ret;
+	TRY_LOCK(ret)
 	if ( !IsLoaded() ) return ret;
 	std::string type;
 	std::string subpath;
@@ -791,6 +854,9 @@ bool Unitsync::FileExists( const std::string& name ) const
 
 std::string Unitsync::GetArchivePath( const std::string& name ) const
 {
+#if ASYNC_LOAD
+	LOCK_UNITSYNC;
+#endif
 	return susynclib().GetArchivePath( name );
 }
 
@@ -818,29 +884,6 @@ public:
 		: m_usync(usync), m_mapname(mapname.c_str()), m_loadMethod(loadMethod) {}
 };
 
-class CacheMinimapWorkItem : public WorkItem
-{
-public:
-	std::string m_mapname;
-
-	void Run()
-	{
-		// Fetch rescaled minimap using this specialized class instead of
-		// CacheMapWorkItem with a pointer to Unitsync::GetMinimap,
-		// to ensure Unitsync::_GetMapInfoEx will be called too, and
-		// hence it's data cached.
-
-		// This reduces main thread blocking while waiting for WorkerThread
-		// to release it's lock while e.g. scrolling through battle list.
-
-		// 98x98 because battle list map preview is 98x98
-		usync().GetMinimap( m_mapname, 98, 98 );
-	}
-
-	CacheMinimapWorkItem( const std::string& mapname )
-		: m_mapname(mapname.c_str()) {}
-};
-
 class GetMapImageAsyncResult : public WorkItem // TODO: rename
 {
 public:
@@ -860,11 +903,15 @@ public:
 		}
 		PostEvent();
 	}
-
 protected:
-	Unitsync* m_usync;
 	std::string m_mapname;
-	int m_evtId;
+	Unitsync* m_usync;
+
+	GetMapImageAsyncResult( Unitsync* usync, const std::string& mapname, int evtId ):
+		m_usync(usync),
+		m_mapname(mapname.c_str())
+	{}
+private:
 
 	void PostEvent()
 	{
@@ -873,11 +920,6 @@ protected:
 
 	virtual void RunCore() = 0;
 
-	GetMapImageAsyncResult( Unitsync* usync, const std::string& mapname, int evtId ):
-		m_usync(usync),
-		m_mapname(mapname.c_str()),
-		m_evtId(evtId)
-	{}
 };
 
 class GetMapImageAsyncWorkItem : public GetMapImageAsyncResult
@@ -947,12 +989,10 @@ public:
 private:
 	Unitsync* m_usync;
 	std::string m_unitsyncloc;
-	int m_evtId;
 public:
 	LoadUnitSyncLibAsyncWorkItem( Unitsync* usync, const std::string& unitsyncLoc):
 		m_usync(usync),
-		m_unitsyncloc(unitsyncLoc.c_str()),
-		m_evtId(ASYNC_UNITSYNC_LOADED_EVT)
+		m_unitsyncloc(unitsyncLoc.c_str())
 	{}
 };
 
@@ -979,12 +1019,6 @@ void Unitsync::PrefetchMap( const std::string& mapname )
 		LslDebug( "cache thread not initialized %s", "PrefetchMap" );
 		return;
 	}
-	{
-		CacheMinimapWorkItem* work;
-
-		work = new CacheMinimapWorkItem( mapname );
-		m_cache_thread->DoWork( work, priority );
-	}
 	{
 		CacheMapWorkItem* work;
 
