@@ -9,9 +9,16 @@ class OfflineBattle : public IBattle
 {
 public:
 	OfflineBattle (const int id = 0 );
-	OfflineBattle ( const OfflineBattle&  );
-	OfflineBattle& operator = ( const OfflineBattle&  );
+
+	OfflineBattle ( const OfflineBattle& ) = delete;
+
+	OfflineBattle ( OfflineBattle&& );
+
+	OfflineBattle& operator = ( const OfflineBattle& ) = delete;
+	OfflineBattle& operator = ( OfflineBattle&&  );
+
 	~OfflineBattle () {}
+
 	virtual User& GetMe() {
 		return m_me;
 	}
@@ -22,7 +29,7 @@ public:
 		return true;
 	}
 	virtual void StartSpring();
-protected:
+private:
 	int m_id;
 	User m_me;
 };
