@@ -16,15 +16,14 @@
 #include <stdexcept>
 
 #include "serverevents.h"
-#include "mainwindow.h"
-#include "ui.h"
-#include "channel/channel.h"
+#include "gui/mainwindow.h"
+#include "gui/ui.h"
+#include "channel.h"
 #include "user.h"
-#include "uiutils.h"
+#include "gui/uiutils.h"
 #include "iserver.h"
-#include "downloader/httpdownloader.h"
 #include "settings.h"
-#include "utils/customdialogs.h"
+#include "gui/customdialogs.h"
 #include "utils/tasutil.h"
 #include "utils/uievents.h"
 #include "log.h"
@@ -46,7 +45,11 @@ void ServerEvents::OnDisconnected( bool wasonline )
 {
 	slLogDebugFunc("");
     m_serv.SetRequiredSpring (wxEmptyString);
-    ui().OnDisconnected( m_serv, wasonline );
+	try {
+		ui().OnDisconnected( m_serv, wasonline );
+	} catch (LSL::Util::GlobalDestroyedError& ) {
+		/* At the end of the program, the global reference in ui() might already have been nullified. */
+	}
 }
 
 
@@ -167,7 +170,7 @@ void ServerEvents::OnUserStatus( const wxString& nick, UserStatus status )
                     battle.SetInGame( status.in_game );
                     if ( status.in_game ) battle.StartSpring();
 					else
-						BattleEvents::GetBattleEventSender( BattleEvents::BattleInfoUpdate ).SendEvent( std::make_pair(user.GetBattle(),wxString()) );
+						BattleEvents::GetBattleEventSender( BattleEvents::BattleInfoUpdate ).SendEvent( std::make_pair(user.GetBattle(),"") );
                 }
             }
             }catch(...){}
@@ -272,8 +275,8 @@ void ServerEvents::OnJoinedBattle( int battleid, const wxString& hash )
 
         if ( !battle.IsFounderMe() || battle.IsProxy() )
         {
-            battle.CustomBattleOptions().loadOptions(LSL::OptionsWrapper::MapOption, battle.GetHostMapName());
-            battle.CustomBattleOptions().loadOptions(LSL::OptionsWrapper::ModOption, battle.GetHostModName());
+            battle.CustomBattleOptions().loadOptions(LSL::Enum::MapOption, battle.GetHostMapName());
+            battle.CustomBattleOptions().loadOptions(LSL::Enum::ModOption, battle.GetHostModName());
         }
 
         ui().OnJoinedBattle( battle );
@@ -293,8 +296,8 @@ void ServerEvents::OnHostedBattle( int battleid )
 
 				if ( battle.GetBattleType() == BT_Played )
 				{
-                    battle.CustomBattleOptions().loadOptions(LSL::OptionsWrapper::MapOption, battle.GetHostMapName());
-                    battle.CustomBattleOptions().loadOptions(LSL::OptionsWrapper::ModOption, battle.GetHostModName());
+                    battle.CustomBattleOptions().loadOptions(LSL::Enum::MapOption, battle.GetHostMapName());
+                    battle.CustomBattleOptions().loadOptions(LSL::Enum::ModOption, battle.GetHostModName());
 				}
 				else
 				{
@@ -411,11 +414,11 @@ void ServerEvents::OnBattleInfoUpdated( int battleid, int spectators, bool locke
         if ( (oldmap != map) && (battle.UserExists( m_serv.GetMe().GetNick())) )
         {
             battle.SendMyBattleStatus();
-            battle.CustomBattleOptions().loadOptions(LSL::OptionsWrapper::MapOption, STD_STRING(map));
-            battle.Update( STD_STRING(wxString::Format( _T("%d_mapname"), LSL::OptionsWrapper::PrivateOptions )));
+            battle.CustomBattleOptions().loadOptions(LSL::Enum::MapOption, STD_STRING(map));
+            battle.Update( STD_STRING(wxString::Format( _T("%d_mapname"), LSL::Enum::PrivateOptions )));
         }
 
-		BattleEvents::GetBattleEventSender( BattleEvents::BattleInfoUpdate ).SendEvent( std::make_pair(&battle,wxString()) );
+		BattleEvents::GetBattleEventSender( BattleEvents::BattleInfoUpdate ).SendEvent( std::make_pair(&battle, "") );
     }
     catch (assert_exception) {}
 }
@@ -434,14 +437,14 @@ void ServerEvents::OnSetBattleInfo( int battleid, const wxString& param, const w
             if ( key.Left( 11 ) == _T( "mapoptions/" ) )
             {
                 key = key.AfterFirst( '/' );
-                battle.CustomBattleOptions().setSingleOption(STD_STRING(key), STD_STRING(value), LSL::OptionsWrapper::MapOption );
-                battle.Update(STD_STRING(wxString::Format(_T("%d_%s"), LSL::OptionsWrapper::MapOption, key.c_str() )));
+                battle.CustomBattleOptions().setSingleOption(STD_STRING(key), STD_STRING(value), LSL::Enum::MapOption );
+                battle.Update(STD_STRING(wxString::Format(_T("%d_%s"), LSL::Enum::MapOption, key.c_str() )));
             }
             else if ( key.Left( 11 ) == _T( "modoptions/" ) )
             {
                 key = key.AfterFirst( '/' );
-                battle.CustomBattleOptions().setSingleOption(STD_STRING(key), STD_STRING(value), LSL::OptionsWrapper::ModOption );
-                battle.Update(STD_STRING(wxString::Format(_T("%d_%s"), LSL::OptionsWrapper::ModOption,  key.c_str() )));
+                battle.CustomBattleOptions().setSingleOption(STD_STRING(key), STD_STRING(value), LSL::Enum::ModOption );
+                battle.Update(STD_STRING(wxString::Format(_T("%d_%s"), LSL::Enum::ModOption,  key.c_str() )));
             }
             else if ( key.Left( 8 ) == _T( "restrict" ) )
             {
@@ -481,8 +484,8 @@ void ServerEvents::OnSetBattleInfo( int battleid, const wxString& param, const w
             }
             else
             {
-                battle.CustomBattleOptions().setSingleOption( STD_STRING(key), STD_STRING(value), LSL::OptionsWrapper::EngineOption );
-                battle.Update(STD_STRING(wxString::Format(_T("%d_%s"), LSL::OptionsWrapper::EngineOption, key.c_str() )));
+                battle.CustomBattleOptions().setSingleOption( STD_STRING(key), STD_STRING(value), LSL::Enum::EngineOption );
+                battle.Update(STD_STRING(wxString::Format(_T("%d_%s"), LSL::Enum::EngineOption, key.c_str() )));
             }
         }
     }
@@ -501,7 +504,7 @@ void ServerEvents::OnBattleInfoUpdated( int battleid )
     try
     {
         IBattle& battle = m_serv.GetBattle( battleid );
-		BattleEvents::GetBattleEventSender( BattleEvents::BattleInfoUpdate ).SendEvent( std::make_pair(&battle,wxString()) );
+		BattleEvents::GetBattleEventSender( BattleEvents::BattleInfoUpdate ).SendEvent( std::make_pair(&battle,"") );
     }
     catch ( assert_exception ) {}
 }
@@ -529,7 +532,7 @@ void ServerEvents::OnBattleDisableUnit( int battleid, const wxString& unitname,
     {
         IBattle& battle = m_serv.GetBattle( battleid );
         battle.RestrictUnit(STD_STRING(unitname), count );
-        battle.Update(STD_STRING(wxString::Format( _T("%d_restrictions"), LSL::OptionsWrapper::PrivateOptions )));
+        battle.Update(STD_STRING(wxString::Format( _T("%d_restrictions"), LSL::Enum::PrivateOptions )));
     }
     catch ( assert_exception ) {}
 }
@@ -542,7 +545,7 @@ void ServerEvents::OnBattleEnableUnit( int battleid, const wxString& unitname )
     {
         IBattle& battle = m_serv.GetBattle( battleid );
         battle.UnrestrictUnit(STD_STRING(unitname));
-        battle.Update(STD_STRING(wxString::Format( _T("%d_restrictions"), LSL::OptionsWrapper::PrivateOptions )));
+        battle.Update(STD_STRING(wxString::Format( _T("%d_restrictions"), LSL::Enum::PrivateOptions )));
     }
     catch ( assert_exception ) {}
 }
@@ -555,7 +558,7 @@ void ServerEvents::OnBattleEnableAllUnits( int battleid )
     {
         IBattle& battle = m_serv.GetBattle( battleid );
         battle.UnrestrictAllUnits();
-        battle.Update(STD_STRING(wxString::Format( _T("%d_restrictions"), LSL::OptionsWrapper::PrivateOptions )));
+        battle.Update(STD_STRING(wxString::Format( _T("%d_restrictions"), LSL::Enum::PrivateOptions )));
     }
     catch ( assert_exception ) {}
 }
@@ -739,7 +742,7 @@ void ServerEvents::OnBattleStartRectAdd( int battleid, int allyno, int left, int
         IBattle& battle = m_serv.GetBattle( battleid );
         battle.AddStartRect( allyno, left, top, right, bottom );
         battle.StartRectAdded( allyno );
-        battle.Update(STD_STRING(wxString::Format( _T("%d_mapname"), LSL::OptionsWrapper::PrivateOptions )));
+        battle.Update(STD_STRING(wxString::Format( _T("%d_mapname"), LSL::Enum::PrivateOptions )));
     }
     catch (assert_exception) {}
 }
@@ -752,7 +755,7 @@ void ServerEvents::OnBattleStartRectRemove( int battleid, int allyno )
         IBattle& battle = m_serv.GetBattle( battleid );
         battle.RemoveStartRect( allyno );
         battle.StartRectRemoved( allyno );
-        battle.Update(STD_STRING(wxString::Format( _T("%d_mapname"), LSL::OptionsWrapper::PrivateOptions )));
+        battle.Update(STD_STRING(wxString::Format( _T("%d_mapname"), LSL::Enum::PrivateOptions )));
     }
     catch (assert_exception) {}
 }
@@ -979,3 +982,18 @@ void ServerEvents::OnForceJoinBattle(int battleid, const wxString &scriptPW)
     UiEvents::GetStatusEventSender( UiEvents::addStatusMessage ).SendEvent(
             UiEvents::StatusData( _("Automatically moved to new battle"), 1 ) );
 }
+
+void ServerEvents::RegistrationAccepted(const wxString& user, const wxString& pass)
+{
+	ui().OnRegistrationAccepted(user, pass);
+}
+
+void ServerEvents::RegistrationDenied(const wxString& reason)
+{
+	ui().OnRegistrationDenied(reason);
+}
+
+void ServerEvents::OnLoginDenied(const wxString& reason)
+{
+	ui().OnLoginDenied(reason);
+}
