@@ -7,8 +7,8 @@
 #include "settings.h"
 
 #include "springsettings/se_utils.h"
-#include "helper/wxTranslationHelper.h"
-#include "helper/slconfig.h"
+#include "utils/wxTranslationHelper.h"
+#include "utils/slconfig.h"
 #include "defines.h" //to get HAVEWX??
 
 #include <wx/filename.h>
@@ -31,19 +31,11 @@
 #include <lslutils/globalsmanager.h>
 #include <lslunitsync/unitsync.h>
 
-#include "nonportable.h"
 #include "utils/conversion.h"
 #include "utils/platform.h"
 #include "utils/slpaths.h"
-#include "uiutils.h"
-#include "playback/playbackfiltervalues.h"
-#include "customlistctrl.h"
+#include "playbackfiltervalues.h"
 #include "springsettings/presets.h"
-#include "helper/sortutil.h"
-#include "mainwindow.h"
-#ifdef SL_DUMMY_COL
-    #include "utils/customdialogs.h"
-#endif
 
 const wxChar sep = wxFileName::GetPathSeparator();
 const wxString sepstring = wxString(sep);
@@ -78,15 +70,16 @@ void Settings::Setup(wxTranslationHelper* translationhelper)
 	long cacheversion = cfg().ReadLong(_T( "/General/CacheVersion" ));
 
 	const wxString userConfigDir = TowxString(SlPaths::GetConfigfileDir());
-	if ( IsFirstRun() && !wxDirExists( userConfigDir ) ) {
-		wxMkdir( userConfigDir );
-	}
 	if ( (cacheversion < CACHE_VERSION) && !IsFirstRun() ) {
-		SlPaths::DeleteAllFilesInDir(SlPaths::GetCachePath());
+		SlPaths::RmDir(SlPaths::GetCachePath());
 		// after resetting cache, set current cache version
 		cfg().Write( _T( "/General/CacheVersion" ), CACHE_VERSION );
 	}
 
+	if ( !wxDirExists( userConfigDir ) ) {
+		wxMkdir( userConfigDir );
+	}
+
 	if ( !cfg().ReadBool(_T("/General/firstrun") )) {
 		ConvertSettings(translationhelper, settversion);
 	}
@@ -1087,12 +1080,6 @@ void Settings::SetDisableSpringVersionCheck(bool disable)
 }
 
 
-wxString Settings::GetTempStorage()
-{
-	return wxFileName::GetTempDir();
-}
-
-
 void Settings::SetShowTooltips( bool show )
 {
 	cfg().Write( _T( "/GUI/ShowTooltips" ), show );
