@@ -4,11 +4,13 @@
 #define SPRINGLOBBY_HEADERGUARD_SETTINGS_H
 
 #include <wx/string.h>
+#include <wx/intl.h>
+
 #include <vector>
 #include <set>
 #include "utils/mixins.h"
 #include "useractions.h"
-#include "helper/sortutil.h"
+#include "utils/sortutil.h"
 
 const long CACHE_VERSION     = 14;
 const long SETTINGS_VERSION  = 27;
@@ -95,8 +97,6 @@ class Settings : public SL::NonCopyable
     bool IsFirstRun();
 
 
-    wxString GetTempStorage();
-
     /* ================================================================ */
     /** @name Network
      * @{
