@@ -32,25 +32,28 @@
 #include <wx/wfstream.h>
 
 #include "springlobbyapp.h"
-#include "mainwindow.h"
+#include "gui/mainwindow.h"
 #include "settings.h"
-#include "helper/slconfig.h"
+#include "utils/slconfig.h"
 #include "crashreport.h"
-#include "utils/controls.h"
+#include "gui/controls.h"
 #include "utils/platform.h"
 #include "utils/version.h"
-#include "channel/channel.h"
-#include "utils/customdialogs.h"
+#include "channel.h"
+#include "gui/customdialogs.h"
 #include "downloader/prdownloader.h"
 #include <lslutils/globalsmanager.h>
 #include <lslutils/config.h>
+#include <lslunitsync/unitsync.h>
 #include "gui/notificationmanager.h"
-#include "helper/wxTranslationHelper.h"
-#include "playback/playbacktraits.h"
-#include "playback/playbacktab.h"
+#include "utils/wxTranslationHelper.h"
+#include "gui/playback/playbacktab.h"
 #include "defines.h"
 #include "utils/slpaths.h"
 #include "downloader/lib/src/FileSystem/FileSystem.h"
+#include "log.h"
+#include "utils/conversion.h"
+#include "gui/ui.h"
 
 #include <wx/debugrpt.h>
 #include <wx/intl.h>
@@ -59,6 +62,7 @@
 	#include <X11/Xlib.h>
 #endif
 
+
 SLCONFIG("/ResetLayout", false, "reset layout on restart");
 
 IMPLEMENT_APP(SpringLobbyApp)
@@ -70,14 +74,25 @@ SpringLobbyApp::SpringLobbyApp():
     quit_called( false ),
     m_translationhelper( NULL ),
     m_log_verbosity( 3 ),
-    m_log_console( true ),
-	m_log_file( false ),
+    m_log_console( false ),
     m_log_window_show( false ),
     m_crash_handle_disable( false ),
 	m_appname( _T("SpringLobby") )
 {
 #if wxUSE_UNIX
-XInitThreads();
+/*
+workarrounds this crash:
+The program 'springlobby' received an X Window System error.
+This probably reflects a bug in the program.
+The error was 'RenderBadPicture (invalid Picture parameter)'.
+  (Details: serial 71245 error_code 143 request_code 139 minor_code 8)
+  (Note to programmers: normally, X errors are reported asynchronously;
+   that is, you will receive the error a while after causing it.
+   To debug your program, run it with the --sync command line
+   option to change this behavior. You can then get a meaningful
+   backtrace from your debugger if you break on the gdk_x_error() function.)
+*/
+	XInitThreads();
 #endif
 }
 
@@ -92,16 +107,12 @@ bool SpringLobbyApp::OnInit()
     if (!wxApp::OnInit())
 		return false;
 	SetAppName( m_appname );
-
-    if (!m_crash_handle_disable) {
-    #if wxUSE_ON_FATAL_EXCEPTION
-        wxHandleFatalExceptions( true );
-    #endif
-    }
+#if wxUSE_ON_FATAL_EXCEPTION
+	wxHandleFatalExceptions( !m_crash_handle_disable );
+#endif
 
     //initialize all loggers, we'll use the returned pointer to set correct parent window later
-    wxLogChain* logchain = 0;
-	wxLogWindow *loggerwin = InitializeLoggingTargets( 0, m_log_console, m_log_file_path, m_log_window_show, m_log_verbosity, logchain );
+	wxLogWindow *loggerwin = Logger::InitializeLoggingTargets( 0, m_log_console, m_log_file_path, m_log_window_show, m_log_verbosity);
 
 	wxLogMessage( _T("SpringLobby %s started"), TowxString(getSpringlobbyVersion()).c_str());
 
@@ -160,7 +171,7 @@ bool SpringLobbyApp::OnInit()
 
 	ui().OnInit();
 
-	ui().mw().SetLogWin( loggerwin, logchain );
+	ui().mw().SetLogWin( loggerwin);
 	return true;
 }
 
@@ -191,16 +202,7 @@ int SpringLobbyApp::OnExit()
 //! @brief is called when the app crashes
 void SpringLobbyApp::OnFatalException()
 {
-#if wxUSE_DEBUGREPORT && defined(ENABLE_DEBUG_REPORT)
-    #if wxUSE_STACKWALKER
-        CrashReport::instance().GenerateReport();
-    #else
-        EXCEPTION_POINTERS* p = new EXCEPTION_POINTERS; //lets hope this'll never get called
-        CrashReport::instance().GenerateReport(p);
-    #endif
-#else
-    wxMessageBox( _("The application has generated a fatal error and will be terminated\nGenerating a bug report is not possible\n\nplease get a wxWidgets library that supports wxUSE_DEBUGREPORT"),_("Critical error"), wxICON_ERROR | wxOK );
-#endif
+	CrashReport::instance().GenerateReport();
 }
 
 
@@ -247,13 +249,13 @@ void SpringLobbyApp::OnInitCmdLine(wxCmdLineParser& parser)
 //! @brief parses the command line and sets global app options like log verbosity or log target
 bool SpringLobbyApp::OnCmdLineParsed(wxCmdLineParser& parser)
 {
-#if wxUSE_CMDLINE_PARSER
     if ( !parser.Parse(true) )
     {
         m_log_console = parser.Found(_T("console-logging"));
         m_log_window_show = parser.Found(_T("gui-logging"));
-		m_log_file = parser.Found(_T("file-logging"), &m_log_file_path);
+		parser.Found(_T("file-logging"), &m_log_file_path);
         m_crash_handle_disable = parser.Found(_T("no-crash-handler"));
+        parser.Found(_T("log-verbosity"), &m_log_verbosity);
 
         // TODO make sure this is called before settings are accessed
 		wxString config;
@@ -270,10 +272,6 @@ bool SpringLobbyApp::OnCmdLineParsed(wxCmdLineParser& parser)
              }
             SlPaths::SetUserConfigPath(STD_STRING(config));
         }
-
-        if ( !parser.Found(_T("log-verbosity"), &m_log_verbosity ) )
-            m_log_verbosity = m_log_window_show ? 3 : 5;
-
         if ( parser.Found(_T("help")) )
             return false; // not a syntax error, but program should stop if user asked for command line usage
 
@@ -283,9 +281,7 @@ bool SpringLobbyApp::OnCmdLineParsed(wxCmdLineParser& parser)
     {
         return false;
     }
-  #else // wxUSE_CMDLINE_PARSER
-  return true;
-  #endif
+
 }
 
 
