@@ -28,7 +28,7 @@ class SpringLobbyApp : public wxApp
 
 	void OnQuit( wxCommandEvent& data );
 
-  protected:
+private:
 
 
     bool quit_called;
@@ -37,7 +37,6 @@ class SpringLobbyApp : public wxApp
 
     long m_log_verbosity;
     bool m_log_console;
-	bool m_log_file;
 	wxString m_log_file_path;
     bool m_log_window_show;
     bool m_crash_handle_disable;
