@@ -7,21 +7,22 @@
 #include <wx/defs.h>
 #include <wx/slider.h>
 #include <wx/log.h>
-#include "../gui/spinctl/spinctrl.h"
 #include <wx/checkbox.h>
 #include <wx/radiobut.h>
 #include <wx/combobox.h>
 #include <wx/textctrl.h>
 #include <wx/display.h>
 
-#include "../utils/customdialogs.h"
-#include <utils/conversion.h>
+#include <lslunitsync/unitsync.h>
+
+#include "gui/spinctl/spinctrl.h"
+#include "gui/customdialogs.h"
+#include "utils/conversion.h"
 #include "ctrlconstants.h"
 #include "se_utils.h"
-#include "../settings.h"
+#include "settings.h"
 #include "presets.h"
 
-#include <lslunitsync/unitsync.h>
 #include "log.h"
 
 
@@ -286,7 +287,7 @@ void abstract_panel::OnSliderMove(wxCommandEvent& event) {
 			(intSettings)[MO_SLI_EXT[4].key]= ( value > 0 ? 1 : 0);
 			} break;
         default:
-            slLogDebugFunc( _T("unhandled case val") );
+            slLogDebugFunc("unhandled case val");
             break;
 	}
 }
@@ -317,7 +318,7 @@ void abstract_panel::OnTextUpdate(wxCommandEvent& event) {
     	    		} break;
 
                     default:
-                        slLogDebugFunc( _T("unhandled case val") );
+                        slLogDebugFunc("unhandled case val");
                         break;
     	    	}
     }
@@ -397,7 +398,7 @@ void abstract_panel::OnCheckBoxTick(wxCommandEvent& event) {
 		case ID_WINDOWC_MO_CBOX_1: { (intSettings)[MO_CBOX[1].key]= checked; } break;
 
         default:
-            slLogDebugFunc( _T("unhandled case val") );
+            slLogDebugFunc("unhandled case val");
             break;
 	}
 }
@@ -421,7 +422,7 @@ void abstract_panel::OnRadioButtonToggle(wxCommandEvent& event) {
 		case ID_WINDOWC_MO_RBUT_4: { (intSettings)[MO_RBUT[4].key]= 4; } break;	// FC button (CamMode 4)
 
         default:
-            slLogDebugFunc( _T("unhandled case val") );
+            slLogDebugFunc("unhandled case val");
             break;
 	}
 }
@@ -451,7 +452,7 @@ void abstract_panel::OnComboBoxChange(wxCommandEvent& event) {
 				case 4: { (intSettings)[WR_COMBOX[0].key]= 4; } break;	// BumpWater
 
                 default:
-                    slLogDebugFunc( _T("unhandled case val") );
+                    slLogDebugFunc("unhandled case val");
                     break;
 			}
 			break;
@@ -550,7 +551,7 @@ void abstract_panel::OnComboBoxChange(wxCommandEvent& event) {
 		}
 
         default:
-            slLogDebugFunc( _T("unhandled case val") );
+            slLogDebugFunc("unhandled case val");
             break;
 	}
 }
