@@ -4,11 +4,10 @@
 //
 
 #include "stacktrace.h"
-#include "utils/conversion.h"
-#if defined(ENABLE_DEBUG_REPORT)
-
 #if wxUSE_STACKWALKER
 
+#include "utils/conversion.h"
+
 void StackTrace::OnStackFrame ( const wxStackFrame& frame )
 {
 //  StackTraceString += wxFormat( _T("(%d) "), frame.GetLevel() ); // (frame_level_number)
@@ -50,6 +49,4 @@ void StackTrace::OnStackFrame ( const wxStackFrame& frame )
 
 }
 
-#endif //__MSW
-
-#endif //#if defined(ENABLE_DEBUG_REPORT)
+#endif
