@@ -31,31 +31,28 @@ lsl/networking/tasserver.cpp
 
 #include <lslunitsync/unitsync.h>
 
-#include "base64.h"
+#include "utils/base64.h"
 #include "utils/md5.h"
 #include "tasserver.h"
 #include "utils/tasutil.h"
 #include "utils/conversion.h"
 #include "utils/platform.h"
-#include "updater/updatehelper.h"
 #include "serverevents.h"
 #include "socket.h"
-#include "tasservertokentable.h"
 #include "log.h"
-#include "utils/customdialogs.h"
-#include "helper/slconfig.h"
+#include "utils/slconfig.h"
 #include "utils/version.h"
 #include "settings.h"
 
 
 SLCONFIG("/Server/ExitMessage", "Using http://springlobby.info/", "Message which is send when leaving server");
-SLCONFIG("/Server/HangTimeout", 10l, "Warn when SpringLobby hangs longer then this delay");
 
-#define PING_TIME 30
-#define PING_TIMEOUT 60
-#define PING_DELAY 5 //first ping is sent after PING_DELAY
-
-const int udp_reply_timeout=10;
+// times in milliseconds
+#define PING_TIME 30000
+#define PING_TIMEOUT 90000
+#define PING_DELAY 5000 //first ping is sent after PING_DELAY
+#define UDP_KEEP_ALIVE 15000
+#define UDP_REPLY_TIMEOUT 10000
 
 
 //! @brief Struct used internally by the TASServer class to get client status information.
@@ -147,9 +144,9 @@ TASServer::TASServer():
 	m_redirecting( false ),
 	m_buffer(wxEmptyString),
 	m_last_udp_ping(0),
-	m_last_ping(time(0) - PING_TIME + PING_DELAY), //no instant ping, delay first ping for PING_DELAY seconds
+	m_last_ping(PING_DELAY), //no instant ping, delay first ping for PING_DELAY seconds
 	m_last_net_packet(0),
-	m_last_timer(0),
+	m_lastnotify(wxGetLocalTimeMillis()),
 	m_last_id(0),
 	m_udp_private_port(0),
 	m_nat_helper_port(0),
@@ -157,11 +154,9 @@ TASServer::TASServer():
 	m_server_lanmode(false),
 	m_account_id_count(0),
 	m_do_finalize_join_battle(false),
-	m_finalize_join_battle_id(-1),
-	m_token_transmission( false )
+	m_finalize_join_battle_id(-1)
 {
 	m_se = new ServerEvents(*this);
-	FillAliasMap();
 	m_relay_host_manager_list.Clear();
 
 	Start(100); // call Update every 100ms
@@ -256,19 +251,25 @@ bool TASServer::ExecuteSayCommand( const wxString& cmd )
 		Disconnect();
 		return true;
 	} else if ( subcmd == _T("/changepassword2") ) {
-		if ( arrayparams.GetCount() < 1 ) return false;
+		if ( arrayparams.GetCount() < 2 ) {
+			m_se->OnServerMessage(_("Missing parameter, usage: /changepassword2 newpassword"));
+			return true;
+		}
 		wxString oldpassword = sett().GetServerAccountPass( GetServerName() );
 		wxString newpassword = GetPasswordHash( params );
 		if  ( oldpassword.IsEmpty() || !sett().GetServerAccountSavePass(GetServerName()) ) {
-			m_se->OnServerMessage(_("There is no saved password for this account, please use /changepassword"));
+			m_se->OnServerMessage(_("There is no saved password for this account, please use /changepassword oldpassword newpassword"));
 			return true;
 		}
 		SendCmd( _T("CHANGEPASSWORD"), oldpassword + _T(" ") + newpassword );
 		return true;
 	} else if ( subcmd == _T("/changepassword") ) {
-		if ( arrayparams.GetCount() != 2 ) return false;
+		if ( arrayparams.GetCount() != 3 ) {
+			m_se->OnServerMessage(_("Invalid parameter count, usage: /changepassword oldpassword newpassword"));
+			return true;
+		}
 		wxString oldpassword = GetPasswordHash(arrayparams[1]);
-		wxString newpassword = GetPasswordHash( arrayparams[2] );
+		wxString newpassword = GetPasswordHash(arrayparams[2]);
 		SendCmd( _T("CHANGEPASSWORD"), oldpassword + _T(" ") + newpassword );
 		return true;
 	} else if ( subcmd == _T("/ping") ) {
@@ -282,7 +283,7 @@ bool TASServer::ExecuteSayCommand( const wxString& cmd )
 void TASServer::Connect( const wxString& servername ,const wxString& addr, const int port )
 {
 	m_server_name = servername;
-	m_addr=addr;
+	m_addr = addr;
 	m_buffer = wxEmptyString;
 	m_sock->Connect( addr, port );
 	m_sock->SetSendRateLimit( 800 ); // 1250 is the server limit but 800 just to make sure :)
@@ -292,7 +293,7 @@ void TASServer::Connect( const wxString& servername ,const wxString& addr, const
 	m_agreement = wxEmptyString;
 	m_crc.ResetCRC();
 	m_last_net_packet = 0;
-	m_last_timer = 0;
+	m_lastnotify = wxGetLocalTimeMillis();
 	const std::string handle = m_sock->GetHandle();
 	if ( !handle.empty() ) {
 		m_crc.UpdateData(handle);
@@ -315,36 +316,12 @@ bool TASServer::IsConnected()
 }
 
 
-bool TASServer::Register( const wxString& addr, const int port, const wxString& nick, const wxString& password, wxString& reason )
+void TASServer::Register(const wxString& servername, const wxString& host, const int port,const wxString& nick, const wxString& password)
 {
-	slLogDebugFunc("");
-	FakeNetClass temp;
-	Socket tempsocket( temp, true, true );
-	tempsocket.Connect( addr, port );
-	if ( tempsocket.State() != SS_Open ) return false;
-
-	wxString data = tempsocket.Receive().BeforeLast(_T('\n'));
-	if ( data.Find( _T("\r") ) != wxNOT_FOUND ) data = data.BeforeLast(_T('\r'));
-	if ( GetWordParam( data ) != _T("TASServer") ) return false;
-
-	tempsocket.Send( _T("REGISTER ") + nick + _T(" ") + GetPasswordHash( password ) + _T("\n") );
-
-	data = tempsocket.Receive().BeforeLast(_T('\n'));
-	tempsocket.Disconnect();
-	if ( data.Find( _T("\r") ) != wxNOT_FOUND ) data = data.BeforeLast(_T('\r'));
-	if ( data.IsEmpty() ) {
-		reason = _("Connection timed out");
-		return false;
-	}
-	wxString cmd = GetWordParam( data );
-	if ( cmd == _T("REGISTRATIONACCEPTED")) {
-		return true;
-	} else if ( cmd == _T("REGISTRATIONDENIED") ) {
-		reason = data;
-		return false;
-	}
-	reason = _("Unknown answer from server");
-	return false;
+	SetUsername(nick);
+	SetPassword(password);
+	Connect(servername, host, port);
+	SendCmd(_T("REGISTER"), nick + _T(" ") + GetPasswordHash( password ) );
 }
 
 
@@ -380,23 +357,23 @@ wxString TASServer::GetPasswordHash( const wxString& pass ) const
 
 User& TASServer::GetMe()
 {
-	return GetUser( m_user );
+	return GetUser( GetUserName() );
 }
 const User& TASServer::GetMe() const
 {
-	return GetUser( m_user );
+	return GetUser( GetUserName() );
 }
 
 void TASServer::Login()
 {
 	slLogDebugFunc("");
-	const wxString pass = GetPasswordHash( m_pass );
+	const wxString pass = GetPasswordHash( GetPassword() );
 	const wxString protocol = TowxString( m_crc.GetCRC() );
 	wxString localaddr = m_sock->GetLocalAddress();
 	if ( localaddr.IsEmpty() ) localaddr = _T("*");
 	m_id_transmission = false;
-	wxFormat login_cmd( _T("%s %s 1337 %s %s\t%s\ta m sp cl p") );
-	SendCmd ( _T("LOGIN"), (login_cmd % m_user % pass % localaddr % TowxString(getSpringlobbyAgent()) % protocol).str() );
+	wxFormat login_cmd( _T("%s %s 0 %s %s\t%s\ta m sp cl p") );
+	SendCmd ( _T("LOGIN"), (login_cmd % GetUserName() % pass % localaddr % TowxString(getSpringlobbyAgent()) % protocol).str() );
 	m_id_transmission = true;
 }
 
@@ -428,12 +405,18 @@ void TASServer::AcceptAgreement()
 void TASServer::Notify()
 {
 	if (m_sock == NULL) return;
-	m_sock->OnTimer(GetInterval());
-	const time_t now = time( 0 );
+	const wxLongLong now = wxGetLocalTimeMillis();
+	const long diff = std::abs((now - m_lastnotify).ToLong());
+	const int interval = std::max<long>(GetInterval(), diff);
+	m_lastnotify = now;
+
+	m_sock->OnTimer(interval);
+	m_last_ping += interval;
+	m_last_net_packet += interval;
+	m_last_udp_ping += interval;
 
 	if ( !m_connected ) { // We are not formally connected yet, but might be.
 		if ( IsConnected() ) {
-			m_last_udp_ping = now;
 			m_connected = true;
 		}
 		return;
@@ -441,54 +424,46 @@ void TASServer::Notify()
 	if ( !IsConnected() ) return;
 
 
-	if (now - m_last_ping > PING_TIME) { //Send a PING every 30 seconds
-		m_last_ping = now;
+	if (m_last_ping > PING_TIME) { //Send a PING every 30 seconds
+		if (interval > PING_TIME) {
+			m_last_net_packet = 0; //assume local clock is broken and we received a packed within time
+			m_se->OnServerMessage(wxFormat(_("Springlobby hung or stale clock. Got no timer for %d msec")) % interval );
+		}
+		m_last_ping = 0;
 		Ping();
 		return;
 	}
 
-	const static long hangcheck = std::max(1l, cfg().ReadLong(_T("/Server/HangTimeout")));
-	if (m_last_timer > 0 && (now-m_last_timer > hangcheck)) {
-		m_se->OnServerMessage(wxFormat(_("SpringLobby hung for %d seconds")) % ((int)now-m_last_timer));
-		m_last_timer = now;
+	if ( m_last_net_packet > PING_TIMEOUT ) {
+		m_se->OnServerMessage(wxFormat(_("Timeout assumed, disconnecting. Received no data from server for %d seconds. Last ping send %d seconds ago.")) % (m_last_net_packet / 1000) % (m_last_ping / 1000) );
+		m_last_net_packet = 0;
+		Disconnect();
 		return;
 	}
-	m_last_timer = now;
-	if ( m_last_net_packet > 0 ) {
-		const time_t lastpacketreceived_diff = now - m_last_net_packet;
-		if ( lastpacketreceived_diff > PING_TIMEOUT ) { // no data received, assume timeout
-			m_se->OnServerMessage(wxFormat(_("Timeout assumed, disconnecting. Received no data from server for %d seconds. Last ping send %d seconds ago.")) % lastpacketreceived_diff % (now - m_last_ping) );
-			Disconnect();
-			return;
-		}
-	}
 
 	// joining battle with nat traversal:
 	// if we havent finalized joining yet, and udp_reply_timeout seconds has passed since
 	// we did UdpPing(our name) , join battle anyway, but with warning message that nat failed.
 	// (if we'd receive reply from server, we'd finalize already)
 	//
-	if (m_do_finalize_join_battle&&(m_last_udp_ping+udp_reply_timeout<now)) {
-		customMessageBoxNoModal(SL_MAIN_ICON,_("Failed to punch through NAT, playing this battle might not work for you or for other players."),_("Error"), wxICON_ERROR);
+	if (m_do_finalize_join_battle&&(m_last_udp_ping > UDP_REPLY_TIMEOUT)) {
+		m_se->OnServerMessage(_("Failed to punch through NAT, playing this battle might not work for you or for other players."));
 		//wxMessageBox()
 		FinalizeJoinBattle();
 		//wxMessageBox(_("Failed to punch through NAT"), _("Error"), wxICON_INFORMATION, NULL/* m_ui.mw()*/ );
-	};
+	}
 
-	if ( ( m_last_udp_ping + m_keepalive ) < now ) {
+	if ( ( m_last_udp_ping > UDP_KEEP_ALIVE )  ) {
 		// Is it time for a nat traversal PING?
-		m_last_udp_ping = now;
+		m_last_udp_ping = 0;
 		// Nat travelsal "ping"
 		if ( m_battle_id != -1 ) {
 			IBattle *battle=GetCurrentBattle();
-			if (battle) {
-				if ( ( battle->GetNatType() == NAT_Hole_punching || ( battle->GetNatType() == NAT_Fixed_source_ports ) ) && !battle->GetInGame() ) {
-					if ( battle->IsFounderMe() ) {
-						UdpPingTheServer(m_user);
-						UdpPingAllClients();
-					} else {
-						UdpPingTheServer(m_user);
-					}
+			if ((battle) &&
+				( battle->GetNatType() == NAT_Hole_punching || ( battle->GetNatType() == NAT_Fixed_source_ports ) ) && !battle->GetInGame() ) {
+				UdpPingTheServer(GetUserName());
+				if ( battle->IsFounderMe() ) {
+					UdpPingAllClients();
 				}
 			}
 		}
@@ -514,15 +489,9 @@ void TASServer::ExecuteCommand( const wxString& in )
 		params = params.AfterFirst( ' ' );
 		id.ToLong( &replyid );
 	}
-	cmd = params.BeforeFirst( ' ' );
+	cmd = params.BeforeFirst( ' ' ).MakeUpper();
 	params = params.AfterFirst( ' ' );
 
-	// decode message if tokenized
-	wxString copy = cmd;
-	cmd = DecodeTokenMessage( cmd );
-	if ( copy != cmd ) m_token_transmission = true;
-	cmd.MakeUpper();
-
 	if ( m_debug_dont_catch ) {
 		ExecuteCommand( cmd, params, replyid );
 	} else {
@@ -545,7 +514,6 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
 	UTASClientStatus tasstatus;
 	UTASBattleStatus tasbstatus;
 	UserBattleStatus bstatus;
-	UTASColor color;
 
 	if ( cmd == _T("TASSERVER")) {
 		mod = GetWordParam( params );
@@ -558,7 +526,7 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
 	} else if ( cmd == _T("ACCEPTED") ) {
 		if ( m_online ) return; // in case is the server sends WTF
 		m_online = true;
-		m_user = params;
+		SetUsername(params);
 		m_se->OnLogin( );
 	} else if ( cmd == _T("MOTD") ) {
 		m_se->OnMotd( params );
@@ -623,7 +591,7 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
 		m_se->OnLoginInfoComplete();
 	} else if ( cmd == _T("REMOVEUSER") ) {
 		nick = GetWordParam( params );
-		if ( nick == m_user ) return; // to prevent peet doing nasty stuff to you, watch your back!
+		if ( nick == GetUserName() ) return; // to prevent peet doing nasty stuff to you, watch your back!
 		m_se->OnUserQuit( nick );
 	} else if ( cmd == _T("BATTLECLOSED") ) {
 		const int id = GetIntParam( params );
@@ -735,8 +703,9 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
 		nick = GetWordParam( params );
 		tasbstatus.data = GetIntParam( params );
 		bstatus = ConvTasbattlestatus( tasbstatus.tasdata );
+		UTASColor color;
 		color.data = GetIntParam( params );
-		bstatus.colour = wxColour( color.color.red, color.color.green, color.color.blue );
+		bstatus.colour = LSL::lslColor(color.color.red, color.color.green, color.color.blue);
 		m_se->OnClientBattleStatus( m_battle_id, nick, bstatus );
 	} else if ( cmd == _T("ADDSTARTRECT") ) {
 		//ADDSTARTRECT allyno left top right bottom
@@ -794,8 +763,9 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
 		owner = GetWordParam( params );
 		tasbstatus.data = GetIntParam( params );
 		bstatus = ConvTasbattlestatus( tasbstatus.tasdata );
+		UTASColor color;
 		color.data = GetIntParam( params );
-		bstatus.colour = wxColour( color.color.red, color.color.green, color.color.blue );
+		bstatus.colour = LSL::lslColor( color.color.red, color.color.green, color.color.blue );
 		ai = GetSentenceParam( params );
 		if ( ai.IsEmpty() ) {
 			wxLogWarning( wxString::Format( _T("Recieved illegal ADDBOT (empty dll field) from %s for battle %d"), nick.c_str(), id ) );
@@ -813,8 +783,9 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
 		nick = GetWordParam( params );
 		tasbstatus.data = GetIntParam( params );
 		bstatus = ConvTasbattlestatus( tasbstatus.tasdata );
+		UTASColor color;
 		color.data = GetIntParam( params );
-		bstatus.colour = wxColour( color.color.red, color.color.green, color.color.blue );
+		bstatus.colour = LSL::lslColor( color.color.red, color.color.green, color.color.blue );
 		m_se->OnBattleUpdateBot( id, nick, bstatus );
 		//UPDATEBOT BATTLE_ID name battlestatus teamcolor
 	} else if ( cmd == _T("REMOVEBOT") ) {
@@ -855,7 +826,7 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
 	} else if ( cmd == _T("DENIED") ) {
 		if ( m_online ) return;
 		m_last_denied = msg = GetSentenceParam( params );
-		m_se->OnServerMessage( msg );
+		m_se->OnLoginDenied( msg );
 		Disconnect();
 		//Command: "DENIED" params: "Already logged in".
 	} else if ( cmd == _T("HOSTPORT") ) {
@@ -911,7 +882,7 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
 		if ( address.IsEmpty() ) return;
 		if ( u_port  == 0 ) u_port  = DEFSETT_DEFAULT_SERVER_PORT;
 		m_redirecting = true;
-		m_se->OnRedirect( address, u_port , m_user, m_pass );
+		m_se->OnRedirect( address, u_port , GetUserName(), GetPassword() );
 	} else if ( cmd == _T("MUTELISTBEGIN") ) {
 		m_current_chan_name_mutelist = GetWordParam( params );
 		m_se->OnMutelistBegin( m_current_chan_name_mutelist );
@@ -927,6 +898,10 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
 		const int battleID = GetIntParam( params );
 		const wxString scriptpw = GetWordParam( params );
 		m_se->OnForceJoinBattle( battleID, scriptpw );
+	} else if ( cmd == _T("REGISTRATIONACCEPTED")) {
+		m_se->RegistrationAccepted(GetUserName(), GetPassword());
+	} else if ( cmd == _T("REGISTRATIONDENIED") ) {
+		m_se->RegistrationDenied(params);
 	} else {
 		wxLogMessage( _T("??? Cmd: %s params: %s"), cmd.c_str(), params.c_str() );
 		m_se->OnUnknownCommand( cmd, params );
@@ -955,9 +930,7 @@ void TASServer::SendCmd( const wxString& command, const wxString& param )
 		m_last_id++;
 		msg = msg + _T("#") + TowxString( m_last_id ) + _T(" ");
 	}
-	if ( m_token_transmission ) {
-		cmd = EncodeTokenMessage( command );
-	} else cmd = command;
+	cmd = command;
 	if ( param.IsEmpty() ) msg = msg + cmd + _T("\n");
 	else msg = msg + cmd + _T(" ") + param + _T("\n");
 	bool send_success = m_sock->Send( msg );
@@ -1236,7 +1209,7 @@ void TASServer::HostBattle( BattleOptions bo, const wxString& password )
 		}
 	}
 
-	if (bo.nattype>0)UdpPingTheServer(m_user);
+	if (bo.nattype>0)UdpPingTheServer(GetUserName());
 
 	// OPENBATTLE type natType password port maphash {map} {title} {modname}
 }
@@ -1257,16 +1230,16 @@ void TASServer::JoinBattle( const int& battleid, const wxString& password )
 			if ( ( battle->GetNatType() == NAT_Hole_punching ) || ( battle->GetNatType() == NAT_Fixed_source_ports ) ) {
 				m_udp_private_port=sett().GetClientPort();
 
-				m_last_udp_ping = time(0);
+				m_last_udp_ping = 0;
 				// its important to set time now, to prevent Update()
 				// from calling FinalizeJoinBattle() on timeout.
 				// m_do_finalize_join_battle must be set to true after setting time, not before.
 				m_do_finalize_join_battle=true;
 				for (int n=0; n<5; ++n) { // do 5 udp pings with tiny interval
-					UdpPingTheServer( m_user );
+					UdpPingTheServer( GetUserName() );
 					// sleep(0);// sleep until end of timeslice.
 				}
-				m_last_udp_ping = time(0);// set time again
+				m_last_udp_ping = 0;// set time again
 			} else {
 				// if not using nat, finalize now.
 				m_do_finalize_join_battle=true;
@@ -1344,7 +1317,7 @@ void TASServer::SendHostInfo( HostInfo update )
 	}
 	if ( ( update & IBattle::HI_Send_All_opts ) > 0 ) {
 		wxString cmd;
-for (const auto& it : battle.CustomBattleOptions().getOptions( LSL::OptionsWrapper::MapOption )) {
+for (const auto& it : battle.CustomBattleOptions().getOptions( LSL::Enum::MapOption )) {
 			const wxString newcmd = TowxString("game/mapoptions/" + it.first + "=" + it.second.second + "\t");
 			if ( cmd.size() + newcmd.size() > 900 ) { // should be 1024 add margin for relayhost name and command itself
 				if ( !battle.IsProxy() ) SendCmd( _T("SETSCRIPTTAGS"), cmd );
@@ -1353,7 +1326,7 @@ for (const auto& it : battle.CustomBattleOptions().getOptions( LSL::OptionsWrapp
 			}
 			cmd << newcmd;
 		}
-for (const auto& it : battle.CustomBattleOptions().getOptions( LSL::OptionsWrapper::ModOption )) {
+		for (const auto& it : battle.CustomBattleOptions().getOptions( LSL::Enum::ModOption )) {
 			const wxString newcmd = TowxString("game/modoptions/" + it.first + "=" + it.second.second + "\t");
 			if ( cmd.size() + newcmd.size() > 900 ) { // should be 1024 add margin for relayhost name and command itself
 				if ( !battle.IsProxy() ) SendCmd( _T("SETSCRIPTTAGS"), cmd );
@@ -1362,7 +1335,7 @@ for (const auto& it : battle.CustomBattleOptions().getOptions( LSL::OptionsWrapp
 			}
 			cmd << newcmd;
 		}
-for (const auto& it : battle.CustomBattleOptions().getOptions( LSL::OptionsWrapper::EngineOption )) {
+		for (const auto& it : battle.CustomBattleOptions().getOptions( LSL::Enum::EngineOption )) {
 			const wxString newcmd = TowxString("game/" + it.first + "=" + it.second.second + "\t");
 			if ( cmd.size() + newcmd.size() > 900 ) { // should be 1024 add margin for relayhost name and command itself
 				if ( !battle.IsProxy() ) SendCmd( _T("SETSCRIPTTAGS"), cmd );
@@ -1449,15 +1422,15 @@ void TASServer::SendHostInfo( const wxString& Tag )
 	long type;
 	Tag.BeforeFirst( '_' ).ToLong( &type );
 	const wxString key = Tag.AfterFirst( '_' );
-	if ( type == LSL::OptionsWrapper::MapOption ) {
+	if ( type == LSL::Enum::MapOption ) {
 		cmd << _T("game/mapoptions/") << key << _T("=")
-		    << TowxString(battle.CustomBattleOptions().getSingleValue(STD_STRING(key), LSL::OptionsWrapper::MapOption ));
-	} else if ( type == LSL::OptionsWrapper::ModOption ) {
+		    << TowxString(battle.CustomBattleOptions().getSingleValue(STD_STRING(key), LSL::Enum::MapOption ));
+	} else if ( type == LSL::Enum::ModOption ) {
 		cmd << _T("game/modoptions/") << key << _T("=")
-		    << TowxString(battle.CustomBattleOptions().getSingleValue(STD_STRING(key), LSL::OptionsWrapper::ModOption ));
-	} else if ( type == LSL::OptionsWrapper::EngineOption ) {
+		    << TowxString(battle.CustomBattleOptions().getSingleValue(STD_STRING(key), LSL::Enum::ModOption ));
+	} else if ( type == LSL::Enum::EngineOption ) {
 		cmd << _T("game/") << key << _T("=")
-		    << TowxString(battle.CustomBattleOptions().getSingleValue(STD_STRING(key), LSL::OptionsWrapper::EngineOption ));
+		    << TowxString(battle.CustomBattleOptions().getSingleValue(STD_STRING(key), LSL::Enum::EngineOption ));
 	}
 	if ( !battle.IsProxy() ) SendCmd( _T("SETSCRIPTTAGS"), cmd );
 	else RelayCmd( _T("SETSCRIPTTAGS"), cmd );
@@ -1559,7 +1532,7 @@ void TASServer::StartHostedBattle()
 	IBattle *battle=GetCurrentBattle();
 	if (battle) {
 		if ( ( battle->GetNatType() == NAT_Hole_punching ) || ( battle->GetNatType() == NAT_Fixed_source_ports ) ) {
-			UdpPingTheServer(m_user);
+			UdpPingTheServer(GetUserName());
 			for (int i=0; i<5; ++i)UdpPingAllClients();
 		}
 	}
@@ -1660,7 +1633,7 @@ void TASServer::ForceAlly( int battleid, User& user, int ally )
 }
 
 
-void TASServer::ForceColour( int battleid, User& user, const wxColour& col )
+void TASServer::ForceColour( int battleid, User& user, const LSL::lslColor& col )
 {
 	slLogDebugFunc("");
 	try {
@@ -1899,10 +1872,8 @@ void TASServer::OnConnected(Socket& /*unused*/ )
 {
 	slLogDebugFunc("");
 	//TASServer* serv = (TASServer*)sock->GetUserdata();
-	m_last_udp_ping = time( 0 );
 	m_connected = true;
 	m_online = false;
-	m_token_transmission = false;
 	m_relay_host_manager_list.Clear();
 	m_last_denied = wxEmptyString;
 	m_last_id = 0;
@@ -1918,7 +1889,6 @@ void TASServer::OnDisconnected(Socket& /*unused*/ )
 	m_connected = false;
 	m_online = false;
 	m_redirecting = false;
-	m_token_transmission = false;
 	m_buffer = wxEmptyString;
 	m_relay_host_manager_list.Clear();
 	m_last_id = 0;
@@ -1933,7 +1903,7 @@ void TASServer::OnDisconnected(Socket& /*unused*/ )
 
 void TASServer::OnDataReceived( Socket& sock )
 {
-	m_last_net_packet = time( 0 );
+	m_last_net_packet = 0;
 	wxString data = sock.Receive();
 	m_buffer << data;
 	m_buffer.Replace( _T("\r\n"), _T("\n") );
@@ -1945,6 +1915,13 @@ void TASServer::OnDataReceived( Socket& sock )
 		returnpos = m_buffer.Find( _T("\n") );
 	}
 }
+void TASServer::OnError(const wxString& err)
+{
+    wxLogError(err);
+	if (m_se != NULL) {
+		m_se->OnServerMessage(err);
+	}
+}
 
 
 //! @brief Send udp ping.
