@@ -22,7 +22,7 @@ lsl/networking/tasserver.h
 #include <list>
 
 #include "iserver.h"
-#include "crc.h"
+#include "utils/crc.h"
 
 const unsigned int FIRST_UDP_SOURCEPORT = 8300;
 
@@ -44,7 +44,7 @@ public:
 	// Overloaded functions from Server
 	bool ExecuteSayCommand( const wxString& cmd );
 
-	bool Register( const wxString& addr, const int port, const wxString& nick, const wxString& password,wxString& reason );
+	void Register( const wxString& servername, const wxString& host, const int port, const wxString& nick, const wxString& password);
 	void AcceptAgreement();
 
 	void Connect( const wxString& servername, const wxString& addr, const int port );
@@ -108,7 +108,7 @@ public:
 	void ForceSide( int battleid, User& user, int side );
 	void ForceTeam( int battleid, User& user, int team );
 	void ForceAlly( int battleid, User& user, int ally );
-	void ForceColour( int battleid, User& user, const wxColour& col );
+	void ForceColour( int battleid, User& user, const LSL::lslColor& col );
 	void ForceSpectator( int battleid, User& user, bool spectator );
 	void BattleKickPlayer( int battleid, User& user );
 	void SetHandicap( int battleid, User& user, int handicap);
@@ -141,6 +141,7 @@ public:
 	void OnConnected(Socket& sock );
 	void OnDisconnected(Socket& sock );
 	void OnDataReceived(Socket& sock );
+	void OnError(const wxString& err);
 
 	bool IsPasswordHash( const wxString& pass )  const;
 	wxString GetPasswordHash( const wxString& pass ) const;
@@ -178,10 +179,10 @@ private:
 	bool m_id_transmission;
 	bool m_redirecting;
 	wxString m_buffer;
-	time_t m_last_udp_ping;
-	time_t m_last_ping; //time last ping was sent
-	time_t m_last_net_packet; //time last packet was received
-	time_t m_last_timer;
+	int m_last_udp_ping;
+	int m_last_ping; //time last ping was sent
+	int m_last_net_packet; //time last packet was received
+	wxLongLong m_lastnotify;
 	unsigned int m_last_id;
 
 	std::list<TASPingListItem> m_pinglist;
@@ -215,6 +216,10 @@ private:
 
 private:
 	void Notify();
+
+    wxString m_relay_host_bot;
+    wxString m_relay_host_manager;
+
 };
 
 #endif // SPRINGLOBBY_HEADERGUARD_TASSERVER_H
