@@ -5,25 +5,18 @@
 
 #include <wx/app.h>
 
-class UpdaterMainwindow;
-
 //! @brief SpringLobby wxApp
 class UpdaterApp : public wxApp
 {
 public:
 	UpdaterApp();
-	~UpdaterApp();
-
+private:
 	virtual bool OnInit();
-	virtual int OnExit();
-
-	virtual void OnFatalException();
+	virtual int OnRun();
 
 	virtual void OnInitCmdLine(wxCmdLineParser& parser);
 	virtual bool OnCmdLineParsed(wxCmdLineParser& parser);
-
-protected:
-	bool StartUpdate( const wxString& source, const wxString& destination )	;
+	bool StartUpdate( const wxString& source, const wxString& destination, bool silent);
 
 	wxString m_source_dir;
 	wxString m_destination_dir;
@@ -32,8 +25,6 @@ protected:
 	long m_pid;
 	long m_paramcount;
 
-	UpdaterMainwindow* m_updater_window;
-
 };
 
 DECLARE_APP(UpdaterApp)
