@@ -12,8 +12,7 @@
 #include <lslutils/misc.h>
 #include <lslutils/conversion.h>
 
-#include "nonportable.h"
-#include "helper/slconfig.h"
+#include "utils/slconfig.h"
 
 #include "platform.h"
 #include "conversion.h"
@@ -29,6 +28,27 @@
 
 std::string SlPaths::m_user_defined_config_path = "";
 
+// returns my documents dir on windows, HOME on windows
+static std::string GetMyDocumentsDir()
+{
+#ifdef WIN32
+	wchar_t my_documents[MAX_PATH];
+	HRESULT result = SHGetFolderPathW(NULL, CSIDL_PERSONAL, NULL, SHGFP_TYPE_CURRENT, my_documents);
+	if (result == S_OK) return LSL::Util::ws2s(my_documents);
+	return "";
+#else
+	const char* envvar= getenv("HOME");
+	if (envvar == NULL) return "";
+	return std::string(envvar);
+#endif
+}
+
+#ifdef WIN32
+SLCONFIG("/Spring/DownloadDir", TowxString(LSL::Util::EnsureDelimiter(GetMyDocumentsDir()) + "My Games\\Spring"), "Path where springlobby stores downloads");
+#else
+SLCONFIG("/Spring/DownloadDir", TowxString(LSL::Util::EnsureDelimiter(GetMyDocumentsDir()) + ".spring"), "Path where springlobby stores downloads");
+#endif
+
 
 std::string SlPaths::GetLocalConfigPath ()
 {
@@ -77,23 +97,6 @@ std::map<std::string, LSL::SpringBundle> SlPaths::GetSpringVersionList()
 	return m_spring_versions;
 }
 
-
-
-// returns my documents dir on windows, HOME on windows
-static std::string GetMyDocumentsDir()
-{
-#ifdef WIN32
-	wchar_t my_documents[MAX_PATH];
-	HRESULT result = SHGetFolderPathW(NULL, CSIDL_PERSONAL, NULL, SHGFP_TYPE_CURRENT, my_documents);
-	if (result == S_OK) return LSL::Util::ws2s(my_documents);
-	return "";
-#else
-	const char* envvar= getenv("HOME");
-	if (envvar == NULL) return "";
-	return std::string(envvar);
-#endif
-}
-
 //returns possible paths where a spring bundles could be
 void SlPaths::PossibleEnginePaths(LSL::StringVector& pl)
 {
@@ -208,12 +211,6 @@ std::string SlPaths::GetCurrentUsedSpringIndex()
 {
 	wxString index = wxEmptyString;
 	cfg().Read(_T("/Spring/CurrentIndex"), &index);
-	if(index.empty()) {
-		// if no version set yet, select one, if available
-		for(auto pair: m_spring_versions) {
-			return pair.first;
-		}
-	}
 	return STD_STRING(index);
 }
 
@@ -235,6 +232,9 @@ void SlPaths::ReconfigureUnitsync()
 
 void SlPaths::DeleteSpringVersionbyIndex( const std::string& index )
 {
+	if (index.empty()) {
+		return;
+	}
 	cfg().DeleteGroup( _T( "/Spring/Paths/" ) + TowxString(index) );
 	if ( GetCurrentUsedSpringIndex() == index ) SetUsedSpringIndex("");
 }
@@ -385,6 +385,11 @@ bool VersionSyncCompatible(const std::string& ver1, const std::string& ver2)
 	 (VersionGetMajor(ver1) == VersionGetMajor(ver2))) {
 		return true;
 	}
+	const std::string ver1trimmed = LSL::Util::BeforeFirst(ver1, " ");
+	const std::string ver2trimmed = LSL::Util::BeforeFirst(ver2, " ");
+	if (!ver1trimmed.empty() && !ver2trimmed.empty() && ver1trimmed == ver2trimmed) { //hack for zk-lobby it sets incomplete version
+		return true;
+	}
 	return false;
 }
 
@@ -426,13 +431,7 @@ std::string SlPaths::GetConfigfileDir()
 
 std::string SlPaths::GetDownloadDir()
 {
-#ifdef WIN32
-	const std::string dir = LSL::Util::EnsureDelimiter(GetMyDocumentsDir()) + "My Games\\Spring";
-#else
-	const std::string dir = LSL::Util::EnsureDelimiter(GetMyDocumentsDir()) + ".spring";
-#endif
-	wxString downloadDir = TowxString(dir);
-	cfg().Read(_T("/Spring/DownloadDir"), &downloadDir);
+	const wxString downloadDir = cfg().ReadString(_T("/Spring/DownloadDir"));
 	return LSL::Util::EnsureDelimiter(STD_STRING(downloadDir));
 }
 
@@ -441,17 +440,24 @@ std::string SlPaths::GetUpdateDir()
 	return SlPaths::GetLobbyWriteDir() + "update" + SEP;
 }
 
-void SlPaths::DeleteAllFilesInDir(const std::string& dir)
+bool SlPaths::RmDir(const std::string& dir)
 {
 	if (dir.empty())
-		return;
+		return false;
 	const wxString cachedir = TowxString(dir);
-	if (wxDirExists(cachedir)) {
-		wxLogWarning( _T("erasing dir %s"), cachedir.c_str());
-		wxString file = wxFindFirstFile( cachedir + wxFILE_SEP_PATH + _T("*") );
-		while ( !file.empty() ) {
-			wxRemoveFile( file );
-			file = wxFindNextFile();
-		}
+	if (!wxDirExists(cachedir)) {
+		return false;
 	}
+	wxLogWarning( _T("erasing dir %s"), cachedir.c_str());
+	wxString file = wxFindFirstFile( cachedir + wxFILE_SEP_PATH + _T("*") );
+	while ( !file.empty() ) {
+		if (wxDirExists(file)) {
+			if (!RmDir(STD_STRING(file))) {
+				return false;
+			}
+		} else if (!wxRemoveFile( file ))
+			return false;
+		file = wxFindNextFile();
+	}
+	return rmdir(dir.c_str()) == 0;
 }
